syntax = "proto3";

package vemmiopb;

import "vemmio_client/pubsub.proto";

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

message MQTTCommandRequest {
  CommandRequest request = 1;
  string response_topic = 2;
}
