# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/websocket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import pubsub_pb2 as vemmio__client_dot_pubsub__pb2
from vemmio_client import reports_pb2 as vemmio__client_dot_reports__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/websocket.proto\x12\x08vemmiopb\x1a\x1avemmio_client/pubsub.proto\x1a\x1bvemmio_client/reports.proto\"\xa7\x01\n\x10WebsocketMessage\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\x04\x12)\n\x07request\x18\x02 \x01(\x0b\x32\x18.vemmiopb.CommandRequest\x12%\n\x05reply\x18\x03 \x01(\x0b\x32\x16.vemmiopb.CommandReply\x12/\n\x0egateway_report\x18\x04 \x01(\x0b\x32\x17.vemmiopb.GatewayReportB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.websocket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _WEBSOCKETMESSAGE._serialized_start=101
  _WEBSOCKETMESSAGE._serialized_end=268
# @@protoc_insertion_point(module_scope)
