syntax = "proto3";

package vemmiopb;

import "vemmio_client/metadata.proto";

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

service Battery {
  rpc BatteryGet(BatteryGetRequest) returns (BatteryGetResponse);
}

message BatteryGetRequest {
  DeviceMetadata metadata = 1;
}

message BatteryGetResponse {
  int32 level = 1;
}

message BatteryReport {
  int32 level = 1;
}
