# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/level.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/level.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cvemmio_client/metadata.proto\":\n\x0cLevelRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x0f\n\rLevelResponse\"L\n\x0fLevelSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05value\x18\x02 \x01(\x05\"\x8f\x01\n\x10LevelStepRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12&\n\x03\x64im\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\'\n\x04\x64own\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"!\n\x10LevelGetResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1c\n\x0bLevelReport\x12\r\n\x05value\x18\x01 \x01(\x05\x32\xd9\x03\n\x05Level\x12>\n\x08LevelGet\x12\x16.vemmiopb.LevelRequest\x1a\x1a.vemmiopb.LevelGetResponse\x12\x42\n\x0cLevelGetStep\x12\x16.vemmiopb.LevelRequest\x1a\x1a.vemmiopb.LevelGetResponse\x12>\n\x08LevelSet\x12\x19.vemmiopb.LevelSetRequest\x1a\x17.vemmiopb.LevelResponse\x12>\n\x07LevelUp\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponse\x12@\n\tLevelDown\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponse\x12\x44\n\rLevelIncrease\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponse\x12\x44\n\rLevelDecrease\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.level_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _LEVELREQUEST._serialized_start=101
  _LEVELREQUEST._serialized_end=159
  _LEVELRESPONSE._serialized_start=161
  _LEVELRESPONSE._serialized_end=176
  _LEVELSETREQUEST._serialized_start=178
  _LEVELSETREQUEST._serialized_end=254
  _LEVELSTEPREQUEST._serialized_start=257
  _LEVELSTEPREQUEST._serialized_end=400
  _LEVELGETRESPONSE._serialized_start=402
  _LEVELGETRESPONSE._serialized_end=435
  _LEVELREPORT._serialized_start=437
  _LEVELREPORT._serialized_end=465
  _LEVEL._serialized_start=468
  _LEVEL._serialized_end=941
# @@protoc_insertion_point(module_scope)
