# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/door.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/door.proto\x12\x08vemmiopb\"0\n\nDoorReport\x12\"\n\x05\x65vent\x18\x01 \x01(\x0e\x32\x13.vemmiopb.DoorEvent*V\n\tDoorEvent\x12\x18\n\x14\x44OOR_EVENT_INTRUSION\x10\x00\x12\x19\n\x15\x44OOR_EVENT_HARD_KNOCK\x10\x01\x12\x14\n\x10\x44OOR_EVENT_KNOCK\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.door_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _DOOREVENT._serialized_start=88
  _DOOREVENT._serialized_end=174
  _DOORREPORT._serialized_start=38
  _DOORREPORT._serialized_end=86
# @@protoc_insertion_point(module_scope)
