# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/heartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/heartbeat.proto\x12\x08vemmiopb\"\x0e\n\x0cHeartbeatMsg2Q\n\tHeartbeat\x12\x44\n\x0eHeartbeatStart\x12\x16.vemmiopb.HeartbeatMsg\x1a\x16.vemmiopb.HeartbeatMsg(\x01\x30\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.heartbeat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _HEARTBEATMSG._serialized_start=43
  _HEARTBEATMSG._serialized_end=57
  _HEARTBEAT._serialized_start=59
  _HEARTBEAT._serialized_end=140
# @@protoc_insertion_point(module_scope)
