# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/power_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n vemmio_client/power_source.proto\x12\x08vemmiopb\">\n\x11PowerSourceReport\x12)\n\x05\x65vent\x18\x01 \x01(\x0e\x32\x1a.vemmiopb.PowerSourceEvent*\xe8\x02\n\x10PowerSourceEvent\x12\t\n\x05\x43LEAR\x10\x00\x12\x11\n\rPOWER_APPLIED\x10\x01\x12\x11\n\rAC_POWER_LOST\x10\x02\x12\x15\n\x11\x41\x43_POWER_RESTORED\x10\x03\x12\x12\n\x0eSURGE_DETECTED\x10\x04\x12\x15\n\x11\x42ROWNOUT_DETECTED\x10\x05\x12\x19\n\x15OVER_CURRENT_DETECTED\x10\x06\x12\x19\n\x15OVER_VOLTAGE_DETECTED\x10\x07\x12\x16\n\x12OVER_LOAD_DETECTED\x10\x08\x12\x0e\n\nLOAD_ERROR\x10\t\x12\x18\n\x14\x42\x41TTERY_REPLACE_SOON\x10\n\x12\x17\n\x13\x42\x41TTERY_REPLACE_NOW\x10\x0b\x12\x14\n\x10\x42\x41TTERY_CHARGING\x10\x0c\x12\x13\n\x0f\x42\x41TTERY_CHARGED\x10\r\x12\x0f\n\x0b\x42\x41TTERY_LOW\x10\x0e\x12\x14\n\x10\x42\x41TTERY_CRITICAL\x10\x0f\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.power_source_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _POWERSOURCEEVENT._serialized_start=111
  _POWERSOURCEEVENT._serialized_end=471
  _POWERSOURCEREPORT._serialized_start=46
  _POWERSOURCEREPORT._serialized_end=108
# @@protoc_insertion_point(module_scope)
