# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/color.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/color.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cvemmio_client/metadata.proto\"\x90\x01\n\x0f\x43olorSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12$\n\x06values\x18\x02 \x03(\x0b\x32\x14.vemmiopb.ColorValue\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x0f\n\rColorResponse\"3\n\x0b\x43olorReport\x12$\n\x06values\x18\x01 \x03(\x0b\x32\x14.vemmiopb.ColorValue\"H\n\nColorValue\x12+\n\tcomponent\x18\x01 \x01(\x0e\x32\x18.vemmiopb.ColorComponent\x12\r\n\x05value\x18\x02 \x01(\x05*\x83\x01\n\x0e\x43olorComponent\x12\x15\n\x11\x43OLOR_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OLOR_WARM_WHITE\x10\x01\x12\x14\n\x10\x43OLOR_COLD_WHITE\x10\x02\x12\r\n\tCOLOR_RED\x10\x03\x12\x0f\n\x0b\x43OLOR_GREEN\x10\x04\x12\x0e\n\nCOLOR_BLUE\x10\x05\x32G\n\x05\x43olor\x12>\n\x08\x43olorSet\x12\x19.vemmiopb.ColorSetRequest\x1a\x17.vemmiopb.ColorResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.color_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _COLORCOMPONENT._serialized_start=393
  _COLORCOMPONENT._serialized_end=524
  _COLORSETREQUEST._serialized_start=102
  _COLORSETREQUEST._serialized_end=246
  _COLORRESPONSE._serialized_start=248
  _COLORRESPONSE._serialized_end=263
  _COLORREPORT._serialized_start=265
  _COLORREPORT._serialized_end=316
  _COLORVALUE._serialized_start=318
  _COLORVALUE._serialized_end=390
  _COLOR._serialized_start=526
  _COLOR._serialized_end=597
# @@protoc_insertion_point(module_scope)
