# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/pubsub.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import addon_pb2 as vemmio__client_dot_addon__pb2
from vemmio_client import admin_pb2 as vemmio__client_dot_admin__pb2
from vemmio_client import battery_pb2 as vemmio__client_dot_battery__pb2
from vemmio_client import ble_pb2 as vemmio__client_dot_ble__pb2
from vemmio_client import carbon_monoxide_pb2 as vemmio__client_dot_carbon__monoxide__pb2
from vemmio_client import color_pb2 as vemmio__client_dot_color__pb2
from vemmio_client import configuration_pb2 as vemmio__client_dot_configuration__pb2
from vemmio_client import devices_pb2 as vemmio__client_dot_devices__pb2
from vemmio_client import firmware_pb2 as vemmio__client_dot_firmware__pb2
from vemmio_client import gate_pb2 as vemmio__client_dot_gate__pb2
from vemmio_client import gateway_pb2 as vemmio__client_dot_gateway__pb2
from vemmio_client import info_pb2 as vemmio__client_dot_info__pb2
from vemmio_client import level_pb2 as vemmio__client_dot_level__pb2
from vemmio_client import lock_pb2 as vemmio__client_dot_lock__pb2
from vemmio_client import messaging_pb2 as vemmio__client_dot_messaging__pb2
from vemmio_client import meter_pb2 as vemmio__client_dot_meter__pb2
from vemmio_client import remote_pb2 as vemmio__client_dot_remote__pb2
from vemmio_client import roller_shutter_pb2 as vemmio__client_dot_roller__shutter__pb2
from vemmio_client import siren_pb2 as vemmio__client_dot_siren__pb2
from vemmio_client import status_pb2 as vemmio__client_dot_status__pb2
from vemmio_client import structure_pb2 as vemmio__client_dot_structure__pb2
from vemmio_client import switch_pb2 as vemmio__client_dot_switch__pb2
from vemmio_client import temperature_pb2 as vemmio__client_dot_temperature__pb2
from vemmio_client import thermostat_pb2 as vemmio__client_dot_thermostat__pb2
from vemmio_client import ultraviolet_pb2 as vemmio__client_dot_ultraviolet__pb2
from vemmio_client import wifi_pb2 as vemmio__client_dot_wifi__pb2
from vemmio_client import zigbee_pb2 as vemmio__client_dot_zigbee__pb2
from vemmio_client import zwave_pb2 as vemmio__client_dot_zwave__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/pubsub.proto\x12\x08vemmiopb\x1a\x19vemmio_client/addon.proto\x1a\x19vemmio_client/admin.proto\x1a\x1bvemmio_client/battery.proto\x1a\x17vemmio_client/ble.proto\x1a#vemmio_client/carbon_monoxide.proto\x1a\x19vemmio_client/color.proto\x1a!vemmio_client/configuration.proto\x1a\x1bvemmio_client/devices.proto\x1a\x1cvemmio_client/firmware.proto\x1a\x18vemmio_client/gate.proto\x1a\x1bvemmio_client/gateway.proto\x1a\x18vemmio_client/info.proto\x1a\x19vemmio_client/level.proto\x1a\x18vemmio_client/lock.proto\x1a\x1dvemmio_client/messaging.proto\x1a\x19vemmio_client/meter.proto\x1a\x1avemmio_client/remote.proto\x1a\"vemmio_client/roller_shutter.proto\x1a\x19vemmio_client/siren.proto\x1a\x1avemmio_client/status.proto\x1a\x1dvemmio_client/structure.proto\x1a\x1avemmio_client/switch.proto\x1a\x1fvemmio_client/temperature.proto\x1a\x1evemmio_client/thermostat.proto\x1a\x1fvemmio_client/ultraviolet.proto\x1a\x18vemmio_client/wifi.proto\x1a\x1avemmio_client/zigbee.proto\x1a\x19vemmio_client/zwave.proto\"0\n\x13MetricsNotification\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x0c\"v\n\x14PresenceNotification\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x12\n\ngit_commit\x18\x03 \x01(\t\x12\x12\n\nbuild_time\x18\x04 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x05 \x01(\t\"\xba\x01\n\x0e\x43ommandRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.vemmiopb.CommandRequestType\x12*\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1c.vemmiopb.CommandRequestData\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12/\n\x07options\x18\x05 \x03(\x0e\x32\x1e.vemmiopb.CommandRequestOption\"\x9f\x01\n\x0c\x43ommandReply\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.vemmiopb.CommandReplyType\x12*\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1b.vemmiopb.CommandReplyError\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1a.vemmiopb.CommandReplyData\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"$\n\x11\x43ommandReplyError\x12\x0f\n\x07message\x18\x01 \x01(\t\"m\n\x10MessagingRequest\x12\'\n\x05\x65mail\x18\x01 \x01(\x0b\x32\x16.vemmiopb.EmailMessageH\x00\x12%\n\x04push\x18\x02 \x01(\x0b\x32\x15.vemmiopb.PushMessageH\x00\x42\t\n\x07message\"\xe3#\n\x12\x43ommandRequestData\x12/\n\tAddonList\x18\x01 \x01(\x0b\x32\x1a.vemmiopb.AddonListRequestH\x00\x12\x41\n\x12\x41\x64\x64onAddThermostat\x18\x02 \x01(\x0b\x32#.vemmiopb.AddonAddThermostatRequestH\x00\x12/\n\tWalkNodes\x18\x65 \x01(\x0b\x32\x1a.vemmiopb.WalkNodesRequestH\x00\x12)\n\x08ReadLogs\x18\x66 \x01(\x0b\x32\x15.vemmiopb.LogsRequestH\x00\x12+\n\nFollowLogs\x18g \x01(\x0b\x32\x15.vemmiopb.LogsRequestH\x00\x12\x32\n\nBatteryGet\x18\x91\x03 \x01(\x0b\x32\x1b.vemmiopb.BatteryGetRequestH\x00\x12.\n\x08\x43olorSet\x18\xf5\x03 \x01(\x0b\x32\x19.vemmiopb.ColorSetRequestH\x00\x12@\n\x11\x43onfigurationList\x18\xd9\x04 \x01(\x0b\x32\".vemmiopb.ConfigurationListRequestH\x00\x12>\n\x10\x43onfigurationGet\x18\xda\x04 \x01(\x0b\x32!.vemmiopb.ConfigurationGetRequestH\x00\x12>\n\x10\x43onfigurationSet\x18\xdb\x04 \x01(\x0b\x32!.vemmiopb.ConfigurationSetRequestH\x00\x12@\n\x11ThermostatModeSet\x18\xbd\x05 \x01(\x0b\x32\".vemmiopb.ThermostatModeSetRequestH\x00\x12\x46\n\x14ThermostatModeSupGet\x18\xbe\x05 \x01(\x0b\x32%.vemmiopb.ThermostatModeSupGetRequestH\x00\x12H\n\x15ThermostatSetpointSet\x18\xbf\x05 \x01(\x0b\x32&.vemmiopb.ThermostatSetpointSetRequestH\x00\x12\x46\n\x14ThermostatFanModeSet\x18\xc0\x05 \x01(\x0b\x32%.vemmiopb.ThermostatFanModeSetRequestH\x00\x12\x34\n\x0b\x44\x65vicesList\x18\xa1\x06 \x01(\x0b\x32\x1c.vemmiopb.DevicesListRequestH\x00\x12\x32\n\x0e\x46irmwareUpload\x18\x85\x07 \x01(\x0b\x32\x17.vemmiopb.FirmwareChunkH\x00\x12<\n\x0f\x46irmwareUpgrade\x18\x86\x07 \x01(\x0b\x32 .vemmiopb.FirmwareUpgradeRequestH\x00\x12:\n\x0e\x46irmwareUpdate\x18\x87\x07 \x01(\x0b\x32\x1f.vemmiopb.FirmwareUpdateRequestH\x00\x12H\n\x15\x46irmwareLatestVersion\x18\x88\x07 \x01(\x0b\x32&.vemmiopb.FirmwareLatestVersionRequestH\x00\x12*\n\x06Reboot\x18\xe9\x07 \x01(\x0b\x32\x17.vemmiopb.RebootRequestH\x00\x12,\n\x07Restart\x18\xea\x07 \x01(\x0b\x32\x18.vemmiopb.RestartRequestH\x00\x12\x31\n\x0cStartSupport\x18\xeb\x07 \x01(\x0b\x32\x18.vemmiopb.SupportRequestH\x00\x12\x30\n\x0bStopSupport\x18\xec\x07 \x01(\x0b\x32\x18.vemmiopb.SupportRequestH\x00\x12&\n\x04Info\x18\xcd\x08 \x01(\x0b\x32\x15.vemmiopb.InfoRequestH\x00\x12+\n\x08LevelGet\x18\xb1\t \x01(\x0b\x32\x16.vemmiopb.LevelRequestH\x00\x12/\n\x0cLevelGetStep\x18\xb2\t \x01(\x0b\x32\x16.vemmiopb.LevelRequestH\x00\x12.\n\x08LevelSet\x18\xb3\t \x01(\x0b\x32\x19.vemmiopb.LevelSetRequestH\x00\x12.\n\x07LevelUp\x18\xb4\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12\x30\n\tLevelDown\x18\xb5\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12\x34\n\rLevelIncrease\x18\xb6\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12\x34\n\rLevelDecrease\x18\xb7\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12,\n\x07LockSet\x18\x95\n \x01(\x0b\x32\x18.vemmiopb.LockSetRequestH\x00\x12.\n\x08MeterGet\x18\xf9\n \x01(\x0b\x32\x19.vemmiopb.MeterGetRequestH\x00\x12\x32\n\nMeterReset\x18\xfa\n \x01(\x0b\x32\x1b.vemmiopb.MeterResetRequestH\x00\x12<\n\x11RollerShutterOpen\x18\xdd\x0b \x01(\x0b\x32\x1e.vemmiopb.RollerShutterRequestH\x00\x12=\n\x12RollerShutterClose\x18\xde\x0b \x01(\x0b\x32\x1e.vemmiopb.RollerShutterRequestH\x00\x12>\n\x10RollerShutterSet\x18\xdf\x0b \x01(\x0b\x32!.vemmiopb.RollerShutterSetRequestH\x00\x12\x38\n\rSirenGetTones\x18\xc1\x0c \x01(\x0b\x32\x1e.vemmiopb.SirenGetTonesRequestH\x00\x12\x38\n\rSirenPlayTone\x18\xc2\x0c \x01(\x0b\x32\x1e.vemmiopb.SirenPlayToneRequestH\x00\x12\x46\n\x14SirenPlayDefaultTone\x18\xc3\x0c \x01(\x0b\x32%.vemmiopb.SirenPlayDefaultToneRequestH\x00\x12\x44\n\x13SirenGetDefaultTone\x18\xc4\x0c \x01(\x0b\x32$.vemmiopb.SirenGetDefaultToneRequestH\x00\x12\x44\n\x13SirenSetDefaultTone\x18\xc5\x0c \x01(\x0b\x32$.vemmiopb.SirenSetDefaultToneRequestH\x00\x12:\n\x0eSirenGetVolume\x18\xc6\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenGetVolumeRequestH\x00\x12:\n\x0eSirenSetVolume\x18\xc7\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenSetVolumeRequestH\x00\x12,\n\x08SwitchOn\x18\xa5\r \x01(\x0b\x32\x17.vemmiopb.SwitchRequestH\x00\x12-\n\tSwitchOff\x18\xa6\r \x01(\x0b\x32\x17.vemmiopb.SwitchRequestH\x00\x12:\n\x0eTemperatureGet\x18\x89\x0e \x01(\x0b\x32\x1f.vemmiopb.TemperatureGetRequestH\x00\x12\x30\n\tWiFiQuery\x18\xed\x0e \x01(\x0b\x32\x1a.vemmiopb.WiFiQueryRequestH\x00\x12.\n\x08WiFiScan\x18\xee\x0e \x01(\x0b\x32\x19.vemmiopb.WiFiScanRequestH\x00\x12\x34\n\x0bWiFiConnect\x18\xef\x0e \x01(\x0b\x32\x1c.vemmiopb.WiFiConnectRequestH\x00\x12\x38\n\rZigbeeInclude\x18\xd1\x0f \x01(\x0b\x32\x1e.vemmiopb.ZigbeeIncludeRequestH\x00\x12\x38\n\rZigbeeExclude\x18\xd2\x0f \x01(\x0b\x32\x1e.vemmiopb.ZigbeeExcludeRequestH\x00\x12\x37\n\x0eZigbeeGetNodes\x18\xd3\x0f \x01(\x0b\x32\x1c.vemmiopb.ZigbeeNodesRequestH\x00\x12\x36\n\x0cZWaveInclude\x18\xb5\x10 \x01(\x0b\x32\x1d.vemmiopb.ZWaveIncludeRequestH\x00\x12\x36\n\x0cZWaveExclude\x18\xb6\x10 \x01(\x0b\x32\x1d.vemmiopb.ZWaveExcludeRequestH\x00\x12\x32\n\nZWaveAbort\x18\xb7\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveAbortRequestH\x00\x12\x36\n\x0eZWaveReadNodes\x18\xb8\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveNodesRequestH\x00\x12\x34\n\x0bZWaveUpdate\x18\xbb\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveUpdateRequestH\x00\x12<\n\x0fZWaveUpdateNode\x18\xbc\x10 \x01(\x0b\x32 .vemmiopb.ZWaveUpdateNodeRequestH\x00\x12\x32\n\nZWaveReset\x18\xbd\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveResetRequestH\x00\x12>\n\x10ZWaveListEntries\x18\xbe\x10 \x01(\x0b\x32!.vemmiopb.ZWaveListEntriesRequestH\x00\x12\x38\n\rZWaveAddEntry\x18\xbf\x10 \x01(\x0b\x32\x1e.vemmiopb.ZWaveAddEntryRequestH\x00\x12>\n\x10ZWaveRemoveEntry\x18\xc0\x10 \x01(\x0b\x32!.vemmiopb.ZWaveRemoveEntryRequestH\x00\x12J\n\x16ZWaveNotificationItems\x18\xc1\x10 \x01(\x0b\x32\'.vemmiopb.ZWaveNotificationItemsRequestH\x00\x12\x30\n\tZWaveTest\x18\xc2\x10 \x01(\x0b\x32\x1a.vemmiopb.ZWaveTestRequestH\x00\x12\x30\n\tZWaveHeal\x18\xc3\x10 \x01(\x0b\x32\x1a.vemmiopb.ZWaveHealRequestH\x00\x12\x42\n\x12ZWaveReplaceFailed\x18\xc4\x10 \x01(\x0b\x32#.vemmiopb.ZWaveReplaceFailedRequestH\x00\x12@\n\x11ZWaveRemoveFailed\x18\xc5\x10 \x01(\x0b\x32\".vemmiopb.ZWaveRemoveFailedRequestH\x00\x12>\n\x10ZWaveHealthCheck\x18\xc6\x10 \x01(\x0b\x32!.vemmiopb.ZWaveHealthCheckRequestH\x00\x12\x34\n\rZWaveReadNode\x18\xc7\x10 \x01(\x0b\x32\x1a.vemmiopb.ZWaveNodeRequestH\x00\x12@\n\x11\x43\x61rbonMonoxideGet\x18\x99\x11 \x01(\x0b\x32\".vemmiopb.CarbonMonoxideGetRequestH\x00\x12:\n\x11\x45nableAdvertising\x18\xfd\x11 \x01(\x0b\x32\x1c.vemmiopb.AdvertisingRequestH\x00\x12;\n\x12\x44isableAdvertising\x18\xfe\x11 \x01(\x0b\x32\x1c.vemmiopb.AdvertisingRequestH\x00\x12:\n\x0eUltravioletGet\x18\xe1\x12 \x01(\x0b\x32\x1f.vemmiopb.UltravioletGetRequestH\x00\x12)\n\x05KeyUp\x18\xc5\x13 \x01(\x0b\x32\x17.vemmiopb.RemoteRequestH\x00\x12+\n\x07KeyDown\x18\xc6\x13 \x01(\x0b\x32\x17.vemmiopb.RemoteRequestH\x00\x12*\n\x08GateOpen\x18\xa9\x14 \x01(\x0b\x32\x15.vemmiopb.GateRequestH\x00\x12+\n\tGateClose\x18\xaa\x14 \x01(\x0b\x32\x15.vemmiopb.GateRequestH\x00\x12+\n\tGateCycle\x18\xab\x14 \x01(\x0b\x32\x15.vemmiopb.GateRequestH\x00\x12\x34\n\x0bStatusCheck\x18\x8d\x15 \x01(\x0b\x32\x1c.vemmiopb.StatusCheckRequestH\x00\x12\x33\n\x0cGetStructure\x18\xf1\x15 \x01(\x0b\x32\x1a.vemmiopb.StructureRequestH\x00\x42\x06\n\x04\x64\x61ta\"\xe5#\n\x10\x43ommandReplyData\x12\x30\n\tAddonList\x18\x01 \x01(\x0b\x32\x1b.vemmiopb.AddonListResponseH\x00\x12\x38\n\x12\x41\x64\x64onAddThermostat\x18\x02 \x01(\x0b\x32\x1a.vemmiopb.AddonAddResponseH\x00\x12\x30\n\tWalkNodes\x18\x65 \x01(\x0b\x32\x1b.vemmiopb.WalkNodesResponseH\x00\x12\'\n\x08ReadLogs\x18\x66 \x01(\x0b\x32\x13.vemmiopb.LogsChunkH\x00\x12)\n\nFollowLogs\x18g \x01(\x0b\x32\x13.vemmiopb.LogsChunkH\x00\x12\x33\n\nBatteryGet\x18\x91\x03 \x01(\x0b\x32\x1c.vemmiopb.BatteryGetResponseH\x00\x12,\n\x08\x43olorSet\x18\xf5\x03 \x01(\x0b\x32\x17.vemmiopb.ColorResponseH\x00\x12\x41\n\x11\x43onfigurationList\x18\xd9\x04 \x01(\x0b\x32#.vemmiopb.ConfigurationListResponseH\x00\x12?\n\x10\x43onfigurationGet\x18\xda\x04 \x01(\x0b\x32\".vemmiopb.ConfigurationGetResponseH\x00\x12?\n\x10\x43onfigurationSet\x18\xdb\x04 \x01(\x0b\x32\".vemmiopb.ConfigurationSetResponseH\x00\x12:\n\x11ThermostatModeSet\x18\xbd\x05 \x01(\x0b\x32\x1c.vemmiopb.ThermostatResponseH\x00\x12G\n\x14ThermostatModeSupGet\x18\xbe\x05 \x01(\x0b\x32&.vemmiopb.ThermostatModeSupGetResponseH\x00\x12>\n\x15ThermostatSetpointSet\x18\xbf\x05 \x01(\x0b\x32\x1c.vemmiopb.ThermostatResponseH\x00\x12=\n\x14ThermostatFanModeSet\x18\xc0\x05 \x01(\x0b\x32\x1c.vemmiopb.ThermostatResponseH\x00\x12\x35\n\x0b\x44\x65vicesList\x18\xa1\x06 \x01(\x0b\x32\x1d.vemmiopb.DevicesListResponseH\x00\x12\x35\n\x0e\x46irmwareUpload\x18\x85\x07 \x01(\x0b\x32\x1a.vemmiopb.FirmwareChunkAckH\x00\x12\x38\n\x0f\x46irmwareUpgrade\x18\x86\x07 \x01(\x0b\x32\x1c.vemmiopb.FirmwareUpgradeAckH\x00\x12;\n\x0e\x46irmwareUpdate\x18\x87\x07 \x01(\x0b\x32 .vemmiopb.FirmwareUpdateResponseH\x00\x12I\n\x15\x46irmwareLatestVersion\x18\x88\x07 \x01(\x0b\x32\'.vemmiopb.FirmwareLatestVersionResponseH\x00\x12+\n\x06Reboot\x18\xe9\x07 \x01(\x0b\x32\x18.vemmiopb.RebootResponseH\x00\x12-\n\x07Restart\x18\xea\x07 \x01(\x0b\x32\x19.vemmiopb.RestartResponseH\x00\x12\x32\n\x0cStartSupport\x18\xeb\x07 \x01(\x0b\x32\x19.vemmiopb.SupportResponseH\x00\x12\x31\n\x0bStopSupport\x18\xec\x07 \x01(\x0b\x32\x19.vemmiopb.SupportResponseH\x00\x12\'\n\x04Info\x18\xcd\x08 \x01(\x0b\x32\x16.vemmiopb.InfoResponseH\x00\x12/\n\x08LevelGet\x18\xb1\t \x01(\x0b\x32\x1a.vemmiopb.LevelGetResponseH\x00\x12\x33\n\x0cLevelGetStep\x18\xb2\t \x01(\x0b\x32\x1a.vemmiopb.LevelGetResponseH\x00\x12,\n\x08LevelSet\x18\xb3\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12+\n\x07LevelUp\x18\xb4\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12-\n\tLevelDown\x18\xb5\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12\x31\n\rLevelIncrease\x18\xb6\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12\x31\n\rLevelDecrease\x18\xb7\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12*\n\x07LockSet\x18\x95\n \x01(\x0b\x32\x16.vemmiopb.LockResponseH\x00\x12/\n\x08MeterGet\x18\xf9\n \x01(\x0b\x32\x1a.vemmiopb.MeterGetResponseH\x00\x12\x33\n\nMeterReset\x18\xfa\n \x01(\x0b\x32\x1c.vemmiopb.MeterResetResponseH\x00\x12=\n\x11RollerShutterOpen\x18\xdd\x0b \x01(\x0b\x32\x1f.vemmiopb.RollerShutterResponseH\x00\x12>\n\x12RollerShutterClose\x18\xde\x0b \x01(\x0b\x32\x1f.vemmiopb.RollerShutterResponseH\x00\x12<\n\x10RollerShutterSet\x18\xdf\x0b \x01(\x0b\x32\x1f.vemmiopb.RollerShutterResponseH\x00\x12\x39\n\rSirenGetTones\x18\xc1\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenGetTonesResponseH\x00\x12\x39\n\rSirenPlayTone\x18\xc2\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenPlayToneResponseH\x00\x12G\n\x14SirenPlayDefaultTone\x18\xc3\x0c \x01(\x0b\x32&.vemmiopb.SirenPlayDefaultToneResponseH\x00\x12\x45\n\x13SirenGetDefaultTone\x18\xc4\x0c \x01(\x0b\x32%.vemmiopb.SirenGetDefaultToneResponseH\x00\x12\x45\n\x13SirenSetDefaultTone\x18\xc5\x0c \x01(\x0b\x32%.vemmiopb.SirenSetDefaultToneResponseH\x00\x12;\n\x0eSirenGetVolume\x18\xc6\x0c \x01(\x0b\x32 .vemmiopb.SirenGetVolumeResponseH\x00\x12;\n\x0eSirenSetVolume\x18\xc7\x0c \x01(\x0b\x32 .vemmiopb.SirenSetVolumeResponseH\x00\x12-\n\x08SwitchOn\x18\xa5\r \x01(\x0b\x32\x18.vemmiopb.SwitchResponseH\x00\x12.\n\tSwitchOff\x18\xa6\r \x01(\x0b\x32\x18.vemmiopb.SwitchResponseH\x00\x12;\n\x0eTemperatureGet\x18\x89\x0e \x01(\x0b\x32 .vemmiopb.TemperatureGetResponseH\x00\x12\x31\n\tWiFiQuery\x18\xed\x0e \x01(\x0b\x32\x1b.vemmiopb.WiFiQueryResponseH\x00\x12/\n\x08WiFiScan\x18\xee\x0e \x01(\x0b\x32\x1a.vemmiopb.WiFiScanResponseH\x00\x12\x35\n\x0bWiFiConnect\x18\xef\x0e \x01(\x0b\x32\x1d.vemmiopb.WiFiConnectResponseH\x00\x12\x39\n\rZigbeeInclude\x18\xd1\x0f \x01(\x0b\x32\x1f.vemmiopb.ZigbeeIncludeResponseH\x00\x12\x39\n\rZigbeeExclude\x18\xd2\x0f \x01(\x0b\x32\x1f.vemmiopb.ZigbeeExcludeResponseH\x00\x12\x38\n\x0eZigbeeGetNodes\x18\xd3\x0f \x01(\x0b\x32\x1d.vemmiopb.ZigbeeNodesResponseH\x00\x12\x35\n\x0cZWaveInclude\x18\xb5\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveIncludeStatusH\x00\x12\x35\n\x0cZWaveExclude\x18\xb6\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveExcludeStatusH\x00\x12\x33\n\nZWaveAbort\x18\xb7\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveAbortResponseH\x00\x12\x37\n\x0eZWaveReadNodes\x18\xb8\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveNodesResponseH\x00\x12\x33\n\x0bZWaveUpdate\x18\xbb\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveUpdateStatusH\x00\x12=\n\x0fZWaveUpdateNode\x18\xbc\x10 \x01(\x0b\x32!.vemmiopb.ZWaveUpdateNodeResponseH\x00\x12\x33\n\nZWaveReset\x18\xbd\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveResetResponseH\x00\x12?\n\x10ZWaveListEntries\x18\xbe\x10 \x01(\x0b\x32\".vemmiopb.ZWaveListEntriesResponseH\x00\x12\x39\n\rZWaveAddEntry\x18\xbf\x10 \x01(\x0b\x32\x1f.vemmiopb.ZWaveAddEntryResponseH\x00\x12?\n\x10ZWaveRemoveEntry\x18\xc0\x10 \x01(\x0b\x32\".vemmiopb.ZWaveRemoveEntryResponseH\x00\x12K\n\x16ZWaveNotificationItems\x18\xc1\x10 \x01(\x0b\x32(.vemmiopb.ZWaveNotificationItemsResponseH\x00\x12\x31\n\tZWaveTest\x18\xc2\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveTestResponseH\x00\x12\x31\n\tZWaveHeal\x18\xc3\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveHealResponseH\x00\x12\x43\n\x12ZWaveReplaceFailed\x18\xc4\x10 \x01(\x0b\x32$.vemmiopb.ZWaveReplaceFailedResponseH\x00\x12\x41\n\x11ZWaveRemoveFailed\x18\xc5\x10 \x01(\x0b\x32#.vemmiopb.ZWaveRemoveFailedResponseH\x00\x12=\n\x10ZWaveHealthCheck\x18\xc6\x10 \x01(\x0b\x32 .vemmiopb.ZWaveHealthCheckStatusH\x00\x12\x35\n\rZWaveReadNode\x18\xc7\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveNodeResponseH\x00\x12\x41\n\x11\x43\x61rbonMonoxideGet\x18\x99\x11 \x01(\x0b\x32#.vemmiopb.CarbonMonoxideGetResponseH\x00\x12;\n\x11\x45nableAdvertising\x18\xfd\x11 \x01(\x0b\x32\x1d.vemmiopb.AdvertisingResponseH\x00\x12<\n\x12\x44isableAdvertising\x18\xfe\x11 \x01(\x0b\x32\x1d.vemmiopb.AdvertisingResponseH\x00\x12;\n\x0eUltravioletGet\x18\xe1\x12 \x01(\x0b\x32 .vemmiopb.UltravioletGetResponseH\x00\x12*\n\x05KeyUp\x18\xc5\x13 \x01(\x0b\x32\x18.vemmiopb.RemoteResponseH\x00\x12,\n\x07KeyDown\x18\xc6\x13 \x01(\x0b\x32\x18.vemmiopb.RemoteResponseH\x00\x12+\n\x08GateOpen\x18\xa9\x14 \x01(\x0b\x32\x16.vemmiopb.GateResponseH\x00\x12,\n\tGateClose\x18\xaa\x14 \x01(\x0b\x32\x16.vemmiopb.GateResponseH\x00\x12,\n\tGateCycle\x18\xab\x14 \x01(\x0b\x32\x16.vemmiopb.GateResponseH\x00\x12\x35\n\x0bStatusCheck\x18\x8d\x15 \x01(\x0b\x32\x1d.vemmiopb.StatusCheckResponseH\x00\x12\x34\n\x0cGetStructure\x18\xf1\x15 \x01(\x0b\x32\x1b.vemmiopb.StructureResponseH\x00\x42\x06\n\x04\x64\x61ta*_\n\x12\x43ommandRequestType\x12\x1c\n\x18REQUEST_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11REQUEST_TYPE_DATA\x10\x01\x12\x14\n\x10REQUEST_TYPE_EOF\x10\x02*o\n\x14\x43ommandRequestOption\x12\x1e\n\x1aREQUEST_OPTION_UNSPECIFIED\x10\x00\x12\x18\n\x14REQUEST_OPTION_NOACK\x10\x01\x12\x1d\n\x19REQUEST_OPTION_NORESPONSE\x10\x02*\x81\x01\n\x10\x43ommandReplyType\x12\x1a\n\x16REPLY_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eREPLY_TYPE_ACK\x10\x01\x12\x14\n\x10REPLY_TYPE_ERROR\x10\x02\x12\x12\n\x0eREPLY_TYPE_EOF\x10\x03\x12\x13\n\x0fREPLY_TYPE_DATA\x10\x04\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.pubsub_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _COMMANDREQUESTTYPE._serialized_start=10691
  _COMMANDREQUESTTYPE._serialized_end=10786
  _COMMANDREQUESTOPTION._serialized_start=10788
  _COMMANDREQUESTOPTION._serialized_end=10899
  _COMMANDREPLYTYPE._serialized_start=10902
  _COMMANDREPLYTYPE._serialized_end=11031
  _METRICSNOTIFICATION._serialized_start=855
  _METRICSNOTIFICATION._serialized_end=903
  _PRESENCENOTIFICATION._serialized_start=905
  _PRESENCENOTIFICATION._serialized_end=1023
  _COMMANDREQUEST._serialized_start=1026
  _COMMANDREQUEST._serialized_end=1212
  _COMMANDREPLY._serialized_start=1215
  _COMMANDREPLY._serialized_end=1374
  _COMMANDREPLYERROR._serialized_start=1376
  _COMMANDREPLYERROR._serialized_end=1412
  _MESSAGINGREQUEST._serialized_start=1414
  _MESSAGINGREQUEST._serialized_end=1523
  _COMMANDREQUESTDATA._serialized_start=1526
  _COMMANDREQUESTDATA._serialized_end=6105
  _COMMANDREPLYDATA._serialized_start=6108
  _COMMANDREPLYDATA._serialized_end=10689
# @@protoc_insertion_point(module_scope)
