# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/switch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/switch.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\";\n\rSwitchRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x10\n\x0eSwitchResponse\"4\n\x0cSwitchReport\x12$\n\x05value\x18\x01 \x01(\x0e\x32\x15.vemmiopb.SwitchValue*@\n\x0bSwitchValue\x12\x12\n\x0eSWITCH_UNKNOWN\x10\x00\x12\r\n\tSWITCH_ON\x10\x01\x12\x0e\n\nSWITCH_OFF\x10\x02\x32\x87\x01\n\x06Switch\x12=\n\x08SwitchOn\x12\x17.vemmiopb.SwitchRequest\x1a\x18.vemmiopb.SwitchResponse\x12>\n\tSwitchOff\x12\x17.vemmiopb.SwitchRequest\x1a\x18.vemmiopb.SwitchResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.switch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _SWITCHVALUE._serialized_start=203
  _SWITCHVALUE._serialized_end=267
  _SWITCHREQUEST._serialized_start=70
  _SWITCHREQUEST._serialized_end=129
  _SWITCHRESPONSE._serialized_start=131
  _SWITCHRESPONSE._serialized_end=147
  _SWITCHREPORT._serialized_start=149
  _SWITCHREPORT._serialized_end=201
  _SWITCH._serialized_start=270
  _SWITCH._serialized_end=405
# @@protoc_insertion_point(module_scope)
