# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/remote.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/remote.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"H\n\rRemoteRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x0b\n\x03key\x18\x02 \x01(\x05\"\x10\n\x0eRemoteResponse\"\x97\x01\n\x0cRemoteReport\x12+\n\x05\x65vent\x18\x01 \x01(\x0e\x32\x1c.vemmiopb.RemoteReport.Event\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0b\n\x03key\x18\x03 \x01(\x05\">\n\x05\x45vent\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PRESSED\x10\x01\x12\x0c\n\x08RELEASED\x10\x02\x12\r\n\tHELD_DOWN\x10\x03\x32\x89\x01\n\rRemoteService\x12:\n\x05KeyUp\x12\x17.vemmiopb.RemoteRequest\x1a\x18.vemmiopb.RemoteResponse\x12<\n\x07KeyDown\x12\x17.vemmiopb.RemoteRequest\x1a\x18.vemmiopb.RemoteResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.remote_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _REMOTEREQUEST._serialized_start=70
  _REMOTEREQUEST._serialized_end=142
  _REMOTERESPONSE._serialized_start=144
  _REMOTERESPONSE._serialized_end=160
  _REMOTEREPORT._serialized_start=163
  _REMOTEREPORT._serialized_end=314
  _REMOTEREPORT_EVENT._serialized_start=252
  _REMOTEREPORT_EVENT._serialized_end=314
  _REMOTESERVICE._serialized_start=317
  _REMOTESERVICE._serialized_end=454
# @@protoc_insertion_point(module_scope)
