# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/ble.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17vemmio_client/ble.proto\x12\x08vemmiopb\"\x14\n\x12\x41\x64vertisingRequest\"\x15\n\x13\x41\x64vertisingResponse2\xb1\x01\n\nBLEService\x12P\n\x11\x45nableAdvertising\x12\x1c.vemmiopb.AdvertisingRequest\x1a\x1d.vemmiopb.AdvertisingResponse\x12Q\n\x12\x44isableAdvertising\x12\x1c.vemmiopb.AdvertisingRequest\x1a\x1d.vemmiopb.AdvertisingResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.ble_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ADVERTISINGREQUEST._serialized_start=37
  _ADVERTISINGREQUEST._serialized_end=57
  _ADVERTISINGRESPONSE._serialized_start=59
  _ADVERTISINGRESPONSE._serialized_end=80
  _BLESERVICE._serialized_start=83
  _BLESERVICE._serialized_end=260
# @@protoc_insertion_point(module_scope)
