# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/status.proto\x12\x08vemmiopb\"\x14\n\x12StatusCheckRequest\"\x15\n\x13StatusCheckResponse\"5\n\x11StatusCheckReport\x12 \n\x06status\x18\x01 \x01(\x0b\x32\x10.vemmiopb.Status\"[\n\x06Status\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x02 \x01(\t\x12\x17\n\x0f\x66irmware_update\x18\x03 \x01(\x08\x12\x11\n\twifi_rssi\x18\x04 \x01(\x05\x32[\n\rStatusService\x12J\n\x0bStatusCheck\x12\x1c.vemmiopb.StatusCheckRequest\x1a\x1d.vemmiopb.StatusCheckResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _STATUSCHECKREQUEST._serialized_start=40
  _STATUSCHECKREQUEST._serialized_end=60
  _STATUSCHECKRESPONSE._serialized_start=62
  _STATUSCHECKRESPONSE._serialized_end=83
  _STATUSCHECKREPORT._serialized_start=85
  _STATUSCHECKREPORT._serialized_end=138
  _STATUS._serialized_start=140
  _STATUS._serialized_end=231
  _STATUSSERVICE._serialized_start=233
  _STATUSSERVICE._serialized_end=324
# @@protoc_insertion_point(module_scope)
