# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/gate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/gate.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"9\n\x0bGateRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x0e\n\x0cGateResponse\"0\n\nGateReport\x12\"\n\x05state\x18\x01 \x01(\x0e\x32\x13.vemmiopb.GateState*P\n\tGateState\x12\x10\n\x0cGATE_UNKNOWN\x10\x00\x12\x0f\n\x0bGATE_OPENED\x10\x01\x12\x0f\n\x0bGATE_CLOSED\x10\x02\x12\x0f\n\x0bGATE_CYCLED\x10\x03\x32\xc0\x01\n\x0bGateService\x12\x39\n\x08GateOpen\x12\x15.vemmiopb.GateRequest\x1a\x16.vemmiopb.GateResponse\x12:\n\tGateClose\x12\x15.vemmiopb.GateRequest\x1a\x16.vemmiopb.GateResponse\x12:\n\tGateCycle\x12\x15.vemmiopb.GateRequest\x1a\x16.vemmiopb.GateResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.gate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _GATESTATE._serialized_start=193
  _GATESTATE._serialized_end=273
  _GATEREQUEST._serialized_start=68
  _GATEREQUEST._serialized_end=125
  _GATERESPONSE._serialized_start=127
  _GATERESPONSE._serialized_end=141
  _GATEREPORT._serialized_start=143
  _GATEREPORT._serialized_end=191
  _GATESERVICE._serialized_start=276
  _GATESERVICE._serialized_end=468
# @@protoc_insertion_point(module_scope)
