# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/siren.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/siren.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"B\n\x14SirenGetTonesRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\";\n\x15SirenGetTonesResponse\x12\"\n\x05tones\x18\x01 \x03(\x0b\x32\x13.vemmiopb.SirenTone\"V\n\x14SirenPlayToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x12\n\ntone_index\x18\x02 \x01(\x05\"\x17\n\x15SirenPlayToneResponse\"I\n\x1bSirenPlayDefaultToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x1e\n\x1cSirenPlayDefaultToneResponse\"H\n\x1aSirenGetDefaultToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"@\n\x1bSirenGetDefaultToneResponse\x12!\n\x04tone\x18\x01 \x01(\x0b\x32\x13.vemmiopb.SirenTone\"\\\n\x1aSirenSetDefaultToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x12\n\ntone_index\x18\x02 \x01(\x05\"\x1d\n\x1bSirenSetDefaultToneResponse\"C\n\x15SirenGetVolumeRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"(\n\x16SirenGetVolumeResponse\x12\x0e\n\x06volume\x18\x01 \x01(\x05\"S\n\x15SirenSetVolumeRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x0e\n\x06volume\x18\x02 \x01(\x05\"\x18\n\x16SirenSetVolumeResponse\")\n\tSirenTone\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"Y\n\x0bSirenReport\x12*\n\x05state\x18\x01 \x01(\x0e\x32\x1b.vemmiopb.SirenReport.State\"\x1e\n\x05State\x12\t\n\x05\x43LEAR\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\"{\n\nToneReport\x12)\n\x05state\x18\x01 \x01(\x0e\x32\x1a.vemmiopb.ToneReport.State\x12\x12\n\ntone_index\x18\x02 \x01(\x05\".\n\x05State\x12\x0c\n\x08INACTIVE\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x02\"\x1e\n\x0cVolumeReport\x12\x0e\n\x06volume\x18\x01 \x01(\x05\x32\x84\x05\n\x05Siren\x12P\n\rSirenGetTones\x12\x1e.vemmiopb.SirenGetTonesRequest\x1a\x1f.vemmiopb.SirenGetTonesResponse\x12P\n\rSirenPlayTone\x12\x1e.vemmiopb.SirenPlayToneRequest\x1a\x1f.vemmiopb.SirenPlayToneResponse\x12\x65\n\x14SirenPlayDefaultTone\x12%.vemmiopb.SirenPlayDefaultToneRequest\x1a&.vemmiopb.SirenPlayDefaultToneResponse\x12\x62\n\x13SirenGetDefaultTone\x12$.vemmiopb.SirenGetDefaultToneRequest\x1a%.vemmiopb.SirenGetDefaultToneResponse\x12\x62\n\x13SirenSetDefaultTone\x12$.vemmiopb.SirenSetDefaultToneRequest\x1a%.vemmiopb.SirenSetDefaultToneResponse\x12S\n\x0eSirenGetVolume\x12\x1f.vemmiopb.SirenGetVolumeRequest\x1a .vemmiopb.SirenGetVolumeResponse\x12S\n\x0eSirenSetVolume\x12\x1f.vemmiopb.SirenSetVolumeRequest\x1a .vemmiopb.SirenSetVolumeResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.siren_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _SIRENGETTONESREQUEST._serialized_start=69
  _SIRENGETTONESREQUEST._serialized_end=135
  _SIRENGETTONESRESPONSE._serialized_start=137
  _SIRENGETTONESRESPONSE._serialized_end=196
  _SIRENPLAYTONEREQUEST._serialized_start=198
  _SIRENPLAYTONEREQUEST._serialized_end=284
  _SIRENPLAYTONERESPONSE._serialized_start=286
  _SIRENPLAYTONERESPONSE._serialized_end=309
  _SIRENPLAYDEFAULTTONEREQUEST._serialized_start=311
  _SIRENPLAYDEFAULTTONEREQUEST._serialized_end=384
  _SIRENPLAYDEFAULTTONERESPONSE._serialized_start=386
  _SIRENPLAYDEFAULTTONERESPONSE._serialized_end=416
  _SIRENGETDEFAULTTONEREQUEST._serialized_start=418
  _SIRENGETDEFAULTTONEREQUEST._serialized_end=490
  _SIRENGETDEFAULTTONERESPONSE._serialized_start=492
  _SIRENGETDEFAULTTONERESPONSE._serialized_end=556
  _SIRENSETDEFAULTTONEREQUEST._serialized_start=558
  _SIRENSETDEFAULTTONEREQUEST._serialized_end=650
  _SIRENSETDEFAULTTONERESPONSE._serialized_start=652
  _SIRENSETDEFAULTTONERESPONSE._serialized_end=681
  _SIRENGETVOLUMEREQUEST._serialized_start=683
  _SIRENGETVOLUMEREQUEST._serialized_end=750
  _SIRENGETVOLUMERESPONSE._serialized_start=752
  _SIRENGETVOLUMERESPONSE._serialized_end=792
  _SIRENSETVOLUMEREQUEST._serialized_start=794
  _SIRENSETVOLUMEREQUEST._serialized_end=877
  _SIRENSETVOLUMERESPONSE._serialized_start=879
  _SIRENSETVOLUMERESPONSE._serialized_end=903
  _SIRENTONE._serialized_start=905
  _SIRENTONE._serialized_end=946
  _SIRENREPORT._serialized_start=948
  _SIRENREPORT._serialized_end=1037
  _SIRENREPORT_STATE._serialized_start=1007
  _SIRENREPORT_STATE._serialized_end=1037
  _TONEREPORT._serialized_start=1039
  _TONEREPORT._serialized_end=1162
  _TONEREPORT_STATE._serialized_start=1116
  _TONEREPORT_STATE._serialized_end=1162
  _VOLUMEREPORT._serialized_start=1164
  _VOLUMEREPORT._serialized_end=1194
  _SIREN._serialized_start=1197
  _SIREN._serialized_end=1841
# @@protoc_insertion_point(module_scope)
