# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/zwave.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from vemmio_client import devices_pb2 as vemmio__client_dot_devices__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/zwave.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bvemmio_client/devices.proto\x1a\x1cvemmio_client/metadata.proto\"%\n\x13ZWaveIncludeRequest\x12\x0e\n\x06secure\x18\x01 \x01(\x08\"\xf6\x02\n\x12ZWaveIncludeStatus\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.vemmiopb.ZWaveIncludeStatus.DeviceFoundH\x00\x12\x39\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x0b\x32(.vemmiopb.ZWaveIncludeStatus.DeviceAddedH\x00\x12:\n\x05ready\x18\x03 \x01(\x0b\x32).vemmiopb.ZWaveIncludeStatus.IncludeReadyH\x00\x12@\n\x08progress\x18\x04 \x01(\x0b\x32,.vemmiopb.ZWaveIncludeStatus.IncludeProgressH\x00\x1a\r\n\x0b\x44\x65viceFound\x1a\x30\n\x0b\x44\x65viceAdded\x12!\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x10.vemmiopb.Device\x1a\x0e\n\x0cIncludeReady\x1a\x11\n\x0fIncludeProgressB\x08\n\x06status\"\x15\n\x13ZWaveExcludeRequest\"\x8e\x03\n\x12ZWaveExcludeStatus\x12=\n\x07removed\x18\x01 \x01(\x0b\x32*.vemmiopb.ZWaveExcludeStatus.DeviceRemovedH\x00\x12:\n\x05ready\x18\x02 \x01(\x0b\x32).vemmiopb.ZWaveExcludeStatus.ExcludeReadyH\x00\x12@\n\x08progress\x18\x03 \x01(\x0b\x32,.vemmiopb.ZWaveExcludeStatus.ExcludeProgressH\x00\x12@\n\tnot_found\x18\x04 \x01(\x0b\x32+.vemmiopb.ZWaveExcludeStatus.DeviceNotFoundH\x00\x1a:\n\rDeviceRemoved\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.vemmiopb.ZWaveMetadata\x1a\x0e\n\x0c\x45xcludeReady\x1a\x11\n\x0f\x45xcludeProgress\x1a\x10\n\x0e\x44\x65viceNotFoundB\x08\n\x06status\"\x13\n\x11ZWaveAbortRequest\"\x14\n\x12ZWaveAbortResponse\"O\n\x10ZWaveTestRequest\x12,\n\x07node_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x13\n\x11ZWaveTestResponse\"\\\n\x10ZWaveHealRequest\x12,\n\x07node_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x1a\n\x12init_return_routes\x18\x02 \x01(\x08\"\x13\n\x11ZWaveHealResponse\",\n\x19ZWaveReplaceFailedRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"\x1c\n\x1aZWaveReplaceFailedResponse\"+\n\x18ZWaveRemoveFailedRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"\x1b\n\x19ZWaveRemoveFailedResponse\"\x19\n\x17ZWaveHealthCheckRequest\"\xca\x01\n\x16ZWaveHealthCheckStatus\x12\x34\n\x07started\x18\x01 \x01(\x0b\x32!.vemmiopb.ZWaveHealthCheckStartedH\x00\x12\x36\n\x08progress\x18\x02 \x01(\x0b\x32\".vemmiopb.ZWaveHealthCheckProgressH\x00\x12\x38\n\tcompleted\x18\x03 \x01(\x0b\x32#.vemmiopb.ZWaveHealthCheckCompletedH\x00\x42\x08\n\x06status\"\x19\n\x17ZWaveHealthCheckStarted\"8\n\x18ZWaveHealthCheckProgress\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\r\n\x05total\x18\x02 \x01(\x05\"K\n\x19ZWaveHealthCheckCompleted\x12.\n\x05nodes\x18\x01 \x03(\x0b\x32\x1f.vemmiopb.ZWaveHealthStatusNode\"h\n\x15ZWaveHealthStatusNode\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12/\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32\x1d.vemmiopb.ZWaveHealthCategory\x12\r\n\x05value\x18\x03 \x01(\x05\"\x13\n\x11ZWaveNodesRequest\"8\n\x12ZWaveNodesResponse\x12\"\n\x05nodes\x18\x01 \x03(\x0b\x32\x13.vemmiopb.ZWaveNode\"#\n\x10ZWaveNodeRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"6\n\x11ZWaveNodeResponse\x12!\n\x04node\x18\x01 \x01(\x0b\x32\x13.vemmiopb.ZWaveNode\"\x14\n\x12ZWaveUpdateRequest\"\xde\x01\n\x11ZWaveUpdateStatus\x12?\n\x08topology\x18\x01 \x01(\x0b\x32+.vemmiopb.ZWaveNetworkTopologyUpdateStartedH\x00\x12<\n\x08neighbor\x18\x02 \x01(\x0b\x32(.vemmiopb.ZWaveNodeNeighborUpdateStartedH\x00\x12@\n\tnode_info\x18\x03 \x01(\x0b\x32+.vemmiopb.ZWaveNodeInformationUpdateStartedH\x00\x42\x08\n\x06status\"#\n!ZWaveNetworkTopologyUpdateStarted\" \n\x1eZWaveNodeNeighborUpdateStarted\"#\n!ZWaveNodeInformationUpdateStarted\")\n\x16ZWaveUpdateNodeRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"\x19\n\x17ZWaveUpdateNodeResponse\"\x13\n\x11ZWaveResetRequest\"\x14\n\x12ZWaveResetResponse\"\xf4\x01\n\tZWaveNode\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x11\n\tvendor_id\x18\x02 \x01(\x05\x12\x14\n\x0cproduct_type\x18\x03 \x01(\x05\x12\x12\n\nproduct_id\x18\x04 \x01(\x05\x12*\n\tendpoints\x18\x05 \x03(\x0b\x32\x17.vemmiopb.ZWaveEndpoint\x12\x19\n\x11manufacturer_name\x18\x06 \x01(\t\x12\x14\n\x0cproduct_name\x18\x07 \x01(\t\x12\x11\n\tuser_name\x18\x08 \x01(\t\x12)\n\x06status\x18\t \x01(\x0e\x32\x19.vemmiopb.ZWaveNodeStatus\"{\n\rZWaveEndpoint\x12\r\n\x05\x65p_id\x18\x01 \x01(\x05\x12\x15\n\rgeneric_class\x18\x02 \x01(\x05\x12\x16\n\x0especific_class\x18\x03 \x01(\x05\x12,\n\ninterfaces\x18\x04 \x03(\x0b\x32\x18.vemmiopb.ZWaveInterface\"\x94\x01\n\x0eZWaveInterface\x12\x15\n\rcommand_class\x18\x01 \x01(\x05\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x14\n\x0creal_version\x18\x04 \x01(\x05\x12\r\n\x05label\x18\x05 \x01(\t\x12\x0c\n\x04help\x18\x06 \x01(\t\x12\'\n\x05items\x18\x07 \x03(\x0b\x32\x18.vemmiopb.ZWaveValueItem\".\n\x0eZWaveValueItem\x12\r\n\x05value\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"\x19\n\x17ZWaveListEntriesRequest\"M\n\x18ZWaveListEntriesResponse\x12\x31\n\x07\x65ntries\x18\x01 \x03(\x0b\x32 .vemmiopb.ZWaveProvisioningEntry\"R\n\x14ZWaveAddEntryRequest\x12\x0b\n\x03\x64sk\x18\x01 \x01(\t\x12-\n\x04info\x18\x02 \x03(\x0b\x32\x1f.vemmiopb.ZWaveProvisioningInfo\"\x17\n\x15ZWaveAddEntryResponse\"&\n\x17ZWaveRemoveEntryRequest\x12\x0b\n\x03\x64sk\x18\x01 \x01(\t\"\x1a\n\x18ZWaveRemoveEntryResponse\"T\n\x16ZWaveProvisioningEntry\x12\x0b\n\x03\x64sk\x18\x01 \x01(\t\x12-\n\x04info\x18\x02 \x03(\x0b\x32\x1f.vemmiopb.ZWaveProvisioningInfo\"\x8f\x03\n\x15ZWaveProvisioningInfo\x12\x42\n\x0cproduct_type\x18\x01 \x01(\x0b\x32*.vemmiopb.ZWaveProvisioningInfoProductTypeH\x00\x12>\n\nproduct_id\x18\x02 \x01(\x0b\x32(.vemmiopb.ZWaveProvisioningInfoProductIDH\x00\x12\x1c\n\x12inclusion_interval\x18\x03 \x01(\x05H\x00\x12\x0e\n\x04uuid\x18\x04 \x01(\tH\x00\x12\x0e\n\x04name\x18\x05 \x01(\tH\x00\x12\x12\n\x08location\x18\x06 \x01(\tH\x00\x12\x1a\n\x10inclusion_status\x18\x07 \x01(\x05H\x00\x12\x16\n\x0cgranted_keys\x18\x08 \x01(\x05H\x00\x12\x1c\n\x12\x62ootstrapping_mode\x18\t \x01(\x05H\x00\x12\x46\n\x0enetwork_status\x18\n \x01(\x0b\x32,.vemmiopb.ZWaveProvisioningInfoNetworkStatusH\x00\x42\x06\n\x04info\"d\n ZWaveProvisioningInfoProductType\x12\x15\n\rgeneric_class\x18\x01 \x01(\x05\x12\x16\n\x0especific_class\x18\x02 \x01(\x05\x12\x11\n\ticon_type\x18\x03 \x01(\x05\"\xa1\x01\n\x1eZWaveProvisioningInfoProductID\x12\x17\n\x0fmanufacturer_id\x18\x01 \x01(\x05\x12\x14\n\x0cproduct_type\x18\x02 \x01(\x05\x12\x12\n\nproduct_id\x18\x03 \x01(\x05\x12\x1b\n\x13\x61pplication_version\x18\x04 \x01(\x05\x12\x1f\n\x17\x61pplication_sub_version\x18\x05 \x01(\x05\"E\n\"ZWaveProvisioningInfoNetworkStatus\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\"N\n\x1dZWaveNotificationItemsRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\r\n\x05\x65p_id\x18\x02 \x01(\x05\x12\r\n\x05index\x18\x03 \x01(\x05\"/\n\x1eZWaveNotificationItemsResponse\x12\r\n\x05items\x18\x01 \x03(\x05*\x95\x01\n\x13ZWaveHealthCategory\x12\x1c\n\x18ZWAVE_HEALTH_UNSPECIFIED\x10\x00\x12\x16\n\x12ZWAVE_HEALTH_GREEN\x10\x01\x12\x17\n\x13ZWAVE_HEALTH_YELLOW\x10\x02\x12\x14\n\x10ZWAVE_HEALTH_RED\x10\x03\x12\x19\n\x15ZWAVE_HEALTH_CRITICAL\x10\x04*r\n\x0fZWaveNodeStatus\x12\x1b\n\x17NODE_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11NODE_STATUS_ALIVE\x10\x01\x12\x14\n\x10NODE_STATUS_DOWN\x10\x02\x12\x15\n\x11NODE_STATUS_SLEEP\x10\x03\x32\x8d\x0b\n\x05ZWave\x12M\n\x0cZWaveInclude\x12\x1d.vemmiopb.ZWaveIncludeRequest\x1a\x1c.vemmiopb.ZWaveIncludeStatus0\x01\x12M\n\x0cZWaveExclude\x12\x1d.vemmiopb.ZWaveExcludeRequest\x1a\x1c.vemmiopb.ZWaveExcludeStatus0\x01\x12G\n\nZWaveAbort\x12\x1b.vemmiopb.ZWaveAbortRequest\x1a\x1c.vemmiopb.ZWaveAbortResponse\x12K\n\x0eZWaveReadNodes\x12\x1b.vemmiopb.ZWaveNodesRequest\x1a\x1c.vemmiopb.ZWaveNodesResponse\x12H\n\rZWaveReadNode\x12\x1a.vemmiopb.ZWaveNodeRequest\x1a\x1b.vemmiopb.ZWaveNodeResponse\x12J\n\x0bZWaveUpdate\x12\x1c.vemmiopb.ZWaveUpdateRequest\x1a\x1b.vemmiopb.ZWaveUpdateStatus0\x01\x12V\n\x0fZWaveUpdateNode\x12 .vemmiopb.ZWaveUpdateNodeRequest\x1a!.vemmiopb.ZWaveUpdateNodeResponse\x12G\n\nZWaveReset\x12\x1b.vemmiopb.ZWaveResetRequest\x1a\x1c.vemmiopb.ZWaveResetResponse\x12Y\n\x10ZWaveListEntries\x12!.vemmiopb.ZWaveListEntriesRequest\x1a\".vemmiopb.ZWaveListEntriesResponse\x12P\n\rZWaveAddEntry\x12\x1e.vemmiopb.ZWaveAddEntryRequest\x1a\x1f.vemmiopb.ZWaveAddEntryResponse\x12Y\n\x10ZWaveRemoveEntry\x12!.vemmiopb.ZWaveRemoveEntryRequest\x1a\".vemmiopb.ZWaveRemoveEntryResponse\x12k\n\x16ZWaveNotificationItems\x12\'.vemmiopb.ZWaveNotificationItemsRequest\x1a(.vemmiopb.ZWaveNotificationItemsResponse\x12\x44\n\tZWaveTest\x12\x1a.vemmiopb.ZWaveTestRequest\x1a\x1b.vemmiopb.ZWaveTestResponse\x12\x44\n\tZWaveHeal\x12\x1a.vemmiopb.ZWaveHealRequest\x1a\x1b.vemmiopb.ZWaveHealResponse\x12_\n\x12ZWaveReplaceFailed\x12#.vemmiopb.ZWaveReplaceFailedRequest\x1a$.vemmiopb.ZWaveReplaceFailedResponse\x12\\\n\x11ZWaveRemoveFailed\x12\".vemmiopb.ZWaveRemoveFailedRequest\x1a#.vemmiopb.ZWaveRemoveFailedResponse\x12Y\n\x10ZWaveHealthCheck\x12!.vemmiopb.ZWaveHealthCheckRequest\x1a .vemmiopb.ZWaveHealthCheckStatus0\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.zwave_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ZWAVEHEALTHCATEGORY._serialized_start=4329
  _ZWAVEHEALTHCATEGORY._serialized_end=4478
  _ZWAVENODESTATUS._serialized_start=4480
  _ZWAVENODESTATUS._serialized_end=4594
  _ZWAVEINCLUDEREQUEST._serialized_start=130
  _ZWAVEINCLUDEREQUEST._serialized_end=167
  _ZWAVEINCLUDESTATUS._serialized_start=170
  _ZWAVEINCLUDESTATUS._serialized_end=544
  _ZWAVEINCLUDESTATUS_DEVICEFOUND._serialized_start=436
  _ZWAVEINCLUDESTATUS_DEVICEFOUND._serialized_end=449
  _ZWAVEINCLUDESTATUS_DEVICEADDED._serialized_start=451
  _ZWAVEINCLUDESTATUS_DEVICEADDED._serialized_end=499
  _ZWAVEINCLUDESTATUS_INCLUDEREADY._serialized_start=501
  _ZWAVEINCLUDESTATUS_INCLUDEREADY._serialized_end=515
  _ZWAVEINCLUDESTATUS_INCLUDEPROGRESS._serialized_start=517
  _ZWAVEINCLUDESTATUS_INCLUDEPROGRESS._serialized_end=534
  _ZWAVEEXCLUDEREQUEST._serialized_start=546
  _ZWAVEEXCLUDEREQUEST._serialized_end=567
  _ZWAVEEXCLUDESTATUS._serialized_start=570
  _ZWAVEEXCLUDESTATUS._serialized_end=968
  _ZWAVEEXCLUDESTATUS_DEVICEREMOVED._serialized_start=847
  _ZWAVEEXCLUDESTATUS_DEVICEREMOVED._serialized_end=905
  _ZWAVEEXCLUDESTATUS_EXCLUDEREADY._serialized_start=907
  _ZWAVEEXCLUDESTATUS_EXCLUDEREADY._serialized_end=921
  _ZWAVEEXCLUDESTATUS_EXCLUDEPROGRESS._serialized_start=923
  _ZWAVEEXCLUDESTATUS_EXCLUDEPROGRESS._serialized_end=940
  _ZWAVEEXCLUDESTATUS_DEVICENOTFOUND._serialized_start=942
  _ZWAVEEXCLUDESTATUS_DEVICENOTFOUND._serialized_end=958
  _ZWAVEABORTREQUEST._serialized_start=970
  _ZWAVEABORTREQUEST._serialized_end=989
  _ZWAVEABORTRESPONSE._serialized_start=991
  _ZWAVEABORTRESPONSE._serialized_end=1011
  _ZWAVETESTREQUEST._serialized_start=1013
  _ZWAVETESTREQUEST._serialized_end=1092
  _ZWAVETESTRESPONSE._serialized_start=1094
  _ZWAVETESTRESPONSE._serialized_end=1113
  _ZWAVEHEALREQUEST._serialized_start=1115
  _ZWAVEHEALREQUEST._serialized_end=1207
  _ZWAVEHEALRESPONSE._serialized_start=1209
  _ZWAVEHEALRESPONSE._serialized_end=1228
  _ZWAVEREPLACEFAILEDREQUEST._serialized_start=1230
  _ZWAVEREPLACEFAILEDREQUEST._serialized_end=1274
  _ZWAVEREPLACEFAILEDRESPONSE._serialized_start=1276
  _ZWAVEREPLACEFAILEDRESPONSE._serialized_end=1304
  _ZWAVEREMOVEFAILEDREQUEST._serialized_start=1306
  _ZWAVEREMOVEFAILEDREQUEST._serialized_end=1349
  _ZWAVEREMOVEFAILEDRESPONSE._serialized_start=1351
  _ZWAVEREMOVEFAILEDRESPONSE._serialized_end=1378
  _ZWAVEHEALTHCHECKREQUEST._serialized_start=1380
  _ZWAVEHEALTHCHECKREQUEST._serialized_end=1405
  _ZWAVEHEALTHCHECKSTATUS._serialized_start=1408
  _ZWAVEHEALTHCHECKSTATUS._serialized_end=1610
  _ZWAVEHEALTHCHECKSTARTED._serialized_start=1612
  _ZWAVEHEALTHCHECKSTARTED._serialized_end=1637
  _ZWAVEHEALTHCHECKPROGRESS._serialized_start=1639
  _ZWAVEHEALTHCHECKPROGRESS._serialized_end=1695
  _ZWAVEHEALTHCHECKCOMPLETED._serialized_start=1697
  _ZWAVEHEALTHCHECKCOMPLETED._serialized_end=1772
  _ZWAVEHEALTHSTATUSNODE._serialized_start=1774
  _ZWAVEHEALTHSTATUSNODE._serialized_end=1878
  _ZWAVENODESREQUEST._serialized_start=1880
  _ZWAVENODESREQUEST._serialized_end=1899
  _ZWAVENODESRESPONSE._serialized_start=1901
  _ZWAVENODESRESPONSE._serialized_end=1957
  _ZWAVENODEREQUEST._serialized_start=1959
  _ZWAVENODEREQUEST._serialized_end=1994
  _ZWAVENODERESPONSE._serialized_start=1996
  _ZWAVENODERESPONSE._serialized_end=2050
  _ZWAVEUPDATEREQUEST._serialized_start=2052
  _ZWAVEUPDATEREQUEST._serialized_end=2072
  _ZWAVEUPDATESTATUS._serialized_start=2075
  _ZWAVEUPDATESTATUS._serialized_end=2297
  _ZWAVENETWORKTOPOLOGYUPDATESTARTED._serialized_start=2299
  _ZWAVENETWORKTOPOLOGYUPDATESTARTED._serialized_end=2334
  _ZWAVENODENEIGHBORUPDATESTARTED._serialized_start=2336
  _ZWAVENODENEIGHBORUPDATESTARTED._serialized_end=2368
  _ZWAVENODEINFORMATIONUPDATESTARTED._serialized_start=2370
  _ZWAVENODEINFORMATIONUPDATESTARTED._serialized_end=2405
  _ZWAVEUPDATENODEREQUEST._serialized_start=2407
  _ZWAVEUPDATENODEREQUEST._serialized_end=2448
  _ZWAVEUPDATENODERESPONSE._serialized_start=2450
  _ZWAVEUPDATENODERESPONSE._serialized_end=2475
  _ZWAVERESETREQUEST._serialized_start=2477
  _ZWAVERESETREQUEST._serialized_end=2496
  _ZWAVERESETRESPONSE._serialized_start=2498
  _ZWAVERESETRESPONSE._serialized_end=2518
  _ZWAVENODE._serialized_start=2521
  _ZWAVENODE._serialized_end=2765
  _ZWAVEENDPOINT._serialized_start=2767
  _ZWAVEENDPOINT._serialized_end=2890
  _ZWAVEINTERFACE._serialized_start=2893
  _ZWAVEINTERFACE._serialized_end=3041
  _ZWAVEVALUEITEM._serialized_start=3043
  _ZWAVEVALUEITEM._serialized_end=3089
  _ZWAVELISTENTRIESREQUEST._serialized_start=3091
  _ZWAVELISTENTRIESREQUEST._serialized_end=3116
  _ZWAVELISTENTRIESRESPONSE._serialized_start=3118
  _ZWAVELISTENTRIESRESPONSE._serialized_end=3195
  _ZWAVEADDENTRYREQUEST._serialized_start=3197
  _ZWAVEADDENTRYREQUEST._serialized_end=3279
  _ZWAVEADDENTRYRESPONSE._serialized_start=3281
  _ZWAVEADDENTRYRESPONSE._serialized_end=3304
  _ZWAVEREMOVEENTRYREQUEST._serialized_start=3306
  _ZWAVEREMOVEENTRYREQUEST._serialized_end=3344
  _ZWAVEREMOVEENTRYRESPONSE._serialized_start=3346
  _ZWAVEREMOVEENTRYRESPONSE._serialized_end=3372
  _ZWAVEPROVISIONINGENTRY._serialized_start=3374
  _ZWAVEPROVISIONINGENTRY._serialized_end=3458
  _ZWAVEPROVISIONINGINFO._serialized_start=3461
  _ZWAVEPROVISIONINGINFO._serialized_end=3860
  _ZWAVEPROVISIONINGINFOPRODUCTTYPE._serialized_start=3862
  _ZWAVEPROVISIONINGINFOPRODUCTTYPE._serialized_end=3962
  _ZWAVEPROVISIONINGINFOPRODUCTID._serialized_start=3965
  _ZWAVEPROVISIONINGINFOPRODUCTID._serialized_end=4126
  _ZWAVEPROVISIONINGINFONETWORKSTATUS._serialized_start=4128
  _ZWAVEPROVISIONINGINFONETWORKSTATUS._serialized_end=4197
  _ZWAVENOTIFICATIONITEMSREQUEST._serialized_start=4199
  _ZWAVENOTIFICATIONITEMSREQUEST._serialized_end=4277
  _ZWAVENOTIFICATIONITEMSRESPONSE._serialized_start=4279
  _ZWAVENOTIFICATIONITEMSRESPONSE._serialized_end=4326
  _ZWAVE._serialized_start=4597
  _ZWAVE._serialized_end=6018
# @@protoc_insertion_point(module_scope)
