syntax = "proto3";

package vemmiopb;

import "vemmio_client/units.proto";

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

message SeismicIntensityReport {
  Unit unit = 1;
  double value = 2;
}

message SeismicMagnitudeReport {
  Unit unit = 1;
  double value = 2;
}
