# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/units.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/units.proto\x12\x08vemmiopb*\xa1\x02\n\x04Unit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43\x45LSIUS\x10\x01\x12\x0e\n\nFAHRENHEIT\x10\x02\x12\x07\n\x03LUX\x10\x03\x12\x0e\n\nPERCENTAGE\x10\x04\x12\x08\n\x04WATT\x10\x05\x12\x0f\n\x0bPULSE_COUNT\x10\x06\x12\x07\n\x03KWH\x10\x07\x12\x08\n\x04KVAH\x10\x08\x12\x08\n\x04VOLT\x10\t\x12\n\n\x06\x41MPERE\x10\n\x12\x10\n\x0cPOWER_FACTOR\x10\x0b\x12\x10\n\x0c\x43UBIC_METERS\x10\x0c\x12\x0e\n\nCUBIC_FEET\x10\r\x12\x0e\n\nUS_GALLONS\x10\x0e\x12\x0b\n\x07\x44\x45GREES\x10\x0f\x12\x1c\n\x18METER_PER_SECOND_SQUARED\x10\x10\x12\x0c\n\x08MERCALLI\x10\x11\x12\x15\n\x11PARTS_PER_MILLION\x10\x12\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.units_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _UNIT._serialized_start=40
  _UNIT._serialized_end=329
# @@protoc_insertion_point(module_scope)
