syntax = "proto3";

package vemmiopb;

import "vemmio_client/metadata.proto";
import "vemmio_client/units.proto";

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

service Temperature {
  rpc TemperatureGet(TemperatureGetRequest) returns (TemperatureGetResponse);
}

message TemperatureGetRequest {
  DeviceMetadata metadata = 1;
  bool refresh = 2;
}

message TemperatureGetResponse {
  Unit unit = 1;
  double value = 2;
}

message TemperatureReport {
  Unit unit = 1;
  double value = 2;
}
