syntax = "proto3";

package vemmiopb;

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

service Heartbeat {
  rpc HeartbeatStart(stream HeartbeatMsg) returns (stream HeartbeatMsg);
}

message HeartbeatMsg {}
