syntax = "proto3";

package vemmiopb;

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

message DoorReport {
  DoorEvent event = 1;
}

enum DoorEvent {
  DOOR_EVENT_INTRUSION = 0;
  DOOR_EVENT_HARD_KNOCK = 1;
  DOOR_EVENT_KNOCK = 2;
}
