# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvemmio_client/metadata.proto\x12\x08vemmiopb\"\xf4\x01\n\x0e\x44\x65viceMetadata\x12(\n\x05zwave\x18\x01 \x01(\x0b\x32\x17.vemmiopb.ZWaveMetadataH\x00\x12*\n\x06zigbee\x18\x02 \x01(\x0b\x32\x18.vemmiopb.ZigbeeMetadataH\x00\x12(\n\x05\x61\x64\x64on\x18\x03 \x01(\x0b\x32\x17.vemmiopb.AddonMetadataH\x00\x12(\n\x05\x61lias\x18\x05 \x01(\x0b\x32\x17.vemmiopb.AliasMetadataH\x00\x12&\n\x04mqtt\x18\x06 \x01(\x0b\x32\x16.vemmiopb.MQTTMetadataH\x00\x42\n\n\x08metadataJ\x04\x08\x04\x10\x05\"5\n\rZWaveMetadata\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x65ndpoint_id\x18\x02 \x01(\x05\"6\n\x0eZigbeeMetadata\x12\x12\n\neui64_addr\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\x05\"\x1d\n\rAddonMetadata\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x1d\n\rAliasMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"!\n\x0cMQTTMetadata\x12\x11\n\tdevice_id\x18\x01 \x01(\x0c\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _DEVICEMETADATA._serialized_start=43
  _DEVICEMETADATA._serialized_end=287
  _ZWAVEMETADATA._serialized_start=289
  _ZWAVEMETADATA._serialized_end=342
  _ZIGBEEMETADATA._serialized_start=344
  _ZIGBEEMETADATA._serialized_end=398
  _ADDONMETADATA._serialized_start=400
  _ADDONMETADATA._serialized_end=429
  _ALIASMETADATA._serialized_start=431
  _ALIASMETADATA._serialized_end=460
  _MQTTMETADATA._serialized_start=462
  _MQTTMETADATA._serialized_end=495
# @@protoc_insertion_point(module_scope)
