# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/carbon_monoxide.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#vemmio_client/carbon_monoxide.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/units.proto\"F\n\x18\x43\x61rbonMonoxideGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"H\n\x19\x43\x61rbonMonoxideGetResponse\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"H\n\x19\x43\x61rbonMonoxideValueReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"\xbd\x01\n\x19\x43\x61rbonMonoxideStateReport\x12,\n\x05state\x18\x01 \x01(\x0e\x32\x1d.vemmiopb.CarbonMonoxideState\x12\x38\n\x0breplacement\x18\x02 \x01(\x0e\x32#.vemmiopb.CarbonMonoxideReplacement\x12\x38\n\x0bmaintenance\x18\x03 \x01(\x0e\x32#.vemmiopb.CarbonMonoxideMaintenance*\xa5\x02\n\x13\x43\x61rbonMonoxideState\x12%\n!CARBON_MONOXIDE_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x43\x41RBON_MONOXIDE_STATE_CLEAR\x10\x01\x12\"\n\x1e\x43\x41RBON_MONOXIDE_STATE_DETECTED\x10\x02\x12\x1e\n\x1a\x43\x41RBON_MONOXIDE_STATE_TEST\x10\x03\x12\"\n\x1e\x43\x41RBON_MONOXIDE_STATE_SILENCED\x10\x04\x12.\n*CARBON_MONOXIDE_STATE_REPLACEMENT_REQUIRED\x10\x05\x12.\n*CARBON_MONOXIDE_STATE_MAINTENANCE_REQUIRED\x10\x06*m\n\x19\x43\x61rbonMonoxideReplacement\x12+\n\'CARBON_MONOXIDE_REPLACEMENT_UNSPECIFIED\x10\x00\x12#\n\x1f\x43\x41RBON_MONOXIDE_REPLACEMENT_EOL\x10\x01*}\n\x19\x43\x61rbonMonoxideMaintenance\x12+\n\'CARBON_MONOXIDE_MAINTENANCE_UNSPECIFIED\x10\x00\x12\x33\n/CARBON_MONOXIDE_MAINTENANCE_PERIODIC_INSPECTION\x10\x01\x32u\n\x15\x43\x61rbonMonoxideService\x12\\\n\x11\x43\x61rbonMonoxideGet\x12\".vemmiopb.CarbonMonoxideGetRequest\x1a#.vemmiopb.CarbonMonoxideGetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.carbon_monoxide_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _CARBONMONOXIDESTATE._serialized_start=519
  _CARBONMONOXIDESTATE._serialized_end=812
  _CARBONMONOXIDEREPLACEMENT._serialized_start=814
  _CARBONMONOXIDEREPLACEMENT._serialized_end=923
  _CARBONMONOXIDEMAINTENANCE._serialized_start=925
  _CARBONMONOXIDEMAINTENANCE._serialized_end=1050
  _CARBONMONOXIDEGETREQUEST._serialized_start=106
  _CARBONMONOXIDEGETREQUEST._serialized_end=176
  _CARBONMONOXIDEGETRESPONSE._serialized_start=178
  _CARBONMONOXIDEGETRESPONSE._serialized_end=250
  _CARBONMONOXIDEVALUEREPORT._serialized_start=252
  _CARBONMONOXIDEVALUEREPORT._serialized_end=324
  _CARBONMONOXIDESTATEREPORT._serialized_start=327
  _CARBONMONOXIDESTATEREPORT._serialized_end=516
  _CARBONMONOXIDESERVICE._serialized_start=1052
  _CARBONMONOXIDESERVICE._serialized_end=1169
# @@protoc_insertion_point(module_scope)
