syntax = "proto3";

package vemmiopb;

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

message EmergencyReport {
  EmergencyType type = 1;
}

enum EmergencyType {
  EMERGENCY_POLICE = 0;
  EMERGENCY_FIRE = 1;
  EMERGENCY_MEDICAL = 2;
}
