# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/emergency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/emergency.proto\x12\x08vemmiopb\"8\n\x0f\x45mergencyReport\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x17.vemmiopb.EmergencyType*P\n\rEmergencyType\x12\x14\n\x10\x45MERGENCY_POLICE\x10\x00\x12\x12\n\x0e\x45MERGENCY_FIRE\x10\x01\x12\x15\n\x11\x45MERGENCY_MEDICAL\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.emergency_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _EMERGENCYTYPE._serialized_start=101
  _EMERGENCYTYPE._serialized_end=181
  _EMERGENCYREPORT._serialized_start=43
  _EMERGENCYREPORT._serialized_end=99
# @@protoc_insertion_point(module_scope)
