syntax = "proto3";

package vemmiopb;

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

enum Unit {
  UNKNOWN = 0;
  CELSIUS = 1;
  FAHRENHEIT = 2;
  LUX = 3;
  PERCENTAGE = 4;
  WATT = 5;
  PULSE_COUNT = 6;
  KWH = 7;
  KVAH = 8;
  VOLT = 9;
  AMPERE = 10;
  POWER_FACTOR = 11;
  CUBIC_METERS = 12;
  CUBIC_FEET = 13;
  US_GALLONS = 14;
  DEGREES = 15;
  METER_PER_SECOND_SQUARED = 16;
  MERCALLI = 17;
  PARTS_PER_MILLION = 18;
}

//SENSOR_UNIT_UNKNOWN = 0x0000;
//SENSOR_UNIT_TEMP_CEL = 0x0100; /**< Air temperature unit: Celsius (C)*/
//SENSOR_UNIT_TEMP_FAHR = 0x0101; /**< Air temperature unit: Fahrenheit (F)*/
//SENSOR_UNIT_GP_PERC = 0x0200; /**< General purpose unit: Percentage value*/
//SENSOR_UNIT_GP_NODIM = 0x0201; /**< General purpose unit: Dimensionless value*/
//SENSOR_UNIT_LUM_PERC = 0x0300; /**< Luminance unit: Percentage value*/
//SENSOR_UNIT_LUM_LUX = 0x0301; /**< Luminance unit: Lux*/
//SENSOR_UNIT_POW_W = 0x0400; /**< Power unit: W*/
//SENSOR_UNIT_POW_BTU = 0x0401; /**< Power unit: Btu/h*/
//SENSOR_UNIT_HUMD_PERC = 0x0500; /**< Relative humidity unit: Percentage value*/
//SENSOR_UNIT_HUMD_ABS = 0x0501; /**< Absolute humidity unit: (g/m3) */
//SENSOR_UNIT_VELO_MS = 0x0600; /**< Velocity unit: m/s*/
//SENSOR_UNIT_VELO_MPH = 0x0601; /**< Velocity unit: mph*/
//SENSOR_UNIT_DIR_DEG = 0x0700; /**< Direction unit: 0 to 360 degrees. 0 = no wind, 90 = east, 180 = south, 270 = west, and 360 = north*/
//SENSOR_UNIT_ATM_KPA = 0x0800; /**< Atmospheric pressure unit: kPa*/
//SENSOR_UNIT_ATM_HG = 0x0801; /**< Atmospheric pressure unit: inches of Mercury*/
//SENSOR_UNIT_BARO_KPA = 0x0900; /**< Barometric pressure unit: kPa*/
//SENSOR_UNIT_BARO_HG = 0x0901; /**< Barometric pressure unit: inches of Mercury*/
//SENSOR_UNIT_SLR_WM2 = 0x0A00; /**< Solar radiation unit: W/m2*/
//SENSOR_UNIT_DEW_CEL = 0x0B00; /**< Dew point unit: Celsius (C)*/
//SENSOR_UNIT_DEW_FAHR = 0x0B01; /**< Dew point unit: Fahrenheit (F)*/
//SENSOR_UNIT_RAIN_MMH = 0x0C00; /**< Rain rate unit: mm/h*/
//SENSOR_UNIT_RAIN_INH = 0x0C01; /**< Rain rate unit: in/h*/
//SENSOR_UNIT_TIDE_M = 0x0D00; /**< Tide level unit: m*/
//SENSOR_UNIT_TIDE_FT = 0x0D01; /**< Tide level unit: feet*/
//SENSOR_UNIT_WGT_KG = 0x0E00; /**< Weight unit: kg*/
//SENSOR_UNIT_WGT_LBS = 0x0E01; /**< Weight unit: pounds*/
//SENSOR_UNIT_VOLT_V = 0x0F00; /**< Voltage unit: V*/
//SENSOR_UNIT_VOLT_MV = 0x0F01; /**< Voltage unit: mV*/
//SENSOR_UNIT_CUR_A = 0x1000; /**< Current unit: A*/
//SENSOR_UNIT_CUR_MA = 0x1001; /**< Current unit: mA*/
//SENSOR_UNIT_CO2_PPM = 0x1100; /**< CO2-level unit: ppm*/
//SENSOR_UNIT_AIR_M3H = 0x1200; /**< Air flow unit: m3/h*/
//SENSOR_UNIT_AIR_CFM = 0x1201; /**< Air flow unit: cfm (cubic feet per minute)*/
//SENSOR_UNIT_TANK_L = 0x1300; /**< Tank capacity unit: l*/
//SENSOR_UNIT_TANK_CBM = 0x1301; /**< Tank capacity unit: cbm*/
//SENSOR_UNIT_TANK_GAL = 0x1302; /**< Tank capacity unit: US gallons*/
//SENSOR_UNIT_DIST_M = 0x1400; /**< Distance unit: m*/
//SENSOR_UNIT_DIST_CM = 0x1401; /**< Distance unit: cm*/
//SENSOR_UNIT_DIST_FT = 0x1402; /**< Distance unit: feet*/
//SENSOR_UNIT_AGL_PERC = 0x1500; /**< Angle Position unit: Percentage value*/
//SENSOR_UNIT_AGL_DEGN = 0x1501; /**< Angle Position unit: Degrees relative to north SensorUnit = pole of standing eye view*/
//SENSOR_UNIT_AGL_DEGS = 0x1502; /**< Angle Position unit: Degrees relative to south SensorUnit = pole of standing eye view*/
//SENSOR_UNIT_ROT_RPM = 0x1600; /**< Rotation unit: rpm (revolutions per minute)*/
//SENSOR_UNIT_ROT_HZ = 0x1601; /**< Rotation unit: Hz (Hertz)*/
//SENSOR_UNIT_WTR_TEMP_CEL = 0x1700; /**< Water temperature unit: Celsius (C)*/
//SENSOR_UNIT_WTR_TEMP_FAHR = 0x1701; /**< Water temperature unit: Fahrenheit (F)*/
//SENSOR_UNIT_SOIL_TEMP_CEL = 0x1800; /**< Soil temperature unit: Celsius (C)*/
//SENSOR_UNIT_SOIL_TEMP_FAHR = 0x1801; /**< Soil temperature unit: Fahrenheit (F)*/
//SENSOR_UNIT_SEIS_INT_MERC = 0x1900; /**< Seismic intensity unit: Mercalli*/
//SENSOR_UNIT_SEIS_INT_EMCRO = 0x1901; /**< Seismic intensity unit: European Macroseismic*/
//SENSOR_UNIT_SEIS_INT_LIEDU = 0x1902; /**< Seismic intensity unit: Liedu*/
//SENSOR_UNIT_SEIS_INT_SHNDO = 0x1903; /**< Seismic intensity unit: Shindo*/
//SENSOR_UNIT_SEIS_MAG_LOCAL = 0x1A00; /**< Seismic magnitude unit: Local (ML)*/
//SENSOR_UNIT_SEIS_MAG_MOM = 0x1A01; /**< Seismic magnitude unit: Moment (MW)*/
//SENSOR_UNIT_SEIS_MAG_SWAVE = 0x1A02; /**< Seismic magnitude unit: Surface wave (MS)*/
//SENSOR_UNIT_SEIS_MAG_BWAVE = 0x1A03; /**< Seismic magnitude unit: Body wave (MB)*/
//SENSOR_UNIT_UV_INDEX = 0x1B00; /**< Ultraviolet unit: UV index*/
//SENSOR_UNIT_ELEC_RES_OHMM = 0x1C00; /**< Electrical resistivity unit: ohm metre*/
//SENSOR_UNIT_ELEC_COND_SIEM = 0x1D00; /**< Electrical conductivity unit: siemens per metre (S/m)*/
//SENSOR_UNIT_LOUDNESS_ABS = 0x1E00; /**< Loudness unit: Absolute loudness (dB)*/
//SENSOR_UNIT_LOUDNESS_A_WT = 0x1E01; /**< Loudness unit: A-weighted decibels (dBA)*/
//SENSOR_UNIT_MOIST_PERC = 0x1F00; /**< Moisture unit: Percentage value*/
//SENSOR_UNIT_MOIST_VOL_WTR = 0x1F01; /**< Moisture unit: Volume water content (m3/m3)*/
//SENSOR_UNIT_MOIST_IMPD = 0x1F02; /**< Moisture unit: Impedance (k ohm)*/
//SENSOR_UNIT_MOIST_WTR_ACT = 0x1F03; /**< Moisture unit: Water activity (aw)*/
//SENSOR_UNIT_FREQ_HZ = 0x2000; /**< Frequency unit: Hz - Must be used until 4.294967295 GHz*/
//SENSOR_UNIT_FREQ_KHZ = 0x2001; /**< Frequency unit: kHz- Must be used until 4.294967295 GHz*/
//SENSOR_UNIT_TIME_SEC = 0x2100; /**< Time unit: seconds*/
//SENSOR_UNIT_TGT_TEMP_CEL = 0x2200; /**< Target temperature unit: Celsius (C)*/
//SENSOR_UNIT_TGT_TEMP_FAHR = 0x2201; /**< Target temperature unit: Fahrenheit (F)*/
//SENSOR_UNIT_PM_2_5_MM3 = 0x2300; /**< Particulate matter 2.5 unit: mole per cubic meter (mol/m3) */
//SENSOR_UNIT_PM_2_5_UGM3 = 0x2301; /**< Particulate matter 2.5 unit: Absolute microgram/cubic meter (ug/m3)*/
//SENSOR_UNIT_F_CH2O_MM3 = 0x2400; /**< Formaldehyde CH2O-level unit: mole per cubic meter (mol/m3) */
//SENSOR_UNIT_RAD_CONT_BQM3 = 0x2500; /**< Radon Concentration unit: Becquerel/cubic meter (bq/m3)*/
//SENSOR_UNIT_RAD_CONT_PCIL = 0x2501; /**< Radon Concentration unit: picocuries/liter (pCi/L)*/
//SENSOR_UNIT_METH_DENS_MM3 = 0x2600; /**< Methane Density CH4 unit: mole per cubic meter (mol/m3) */
//SENSOR_UNIT_VOC_MM3 = 0x2700; /**< Volatile Organic unit: mole per cubic meter (mol/m3) */
//SENSOR_UNIT_CO_LVL_MM3 = 0x2800; /**< Carbon Monoxide CO-level unit: mole per cubic meter (mol/m3) */
//SENSOR_UNIT_SOIL_HUMD_PERC = 0x2900; /**< Soil Humidity unit: Percentage value */
//SENSOR_UNIT_SOIL_REAC_PH = 0x2A00; /**< Soil Reactivity unit: acidity (pH) */
//SENSOR_UNIT_SOIL_SAL_MM3 = 0x2B00; /**< Soil Salinity unit: mole per cubic meter (mol/m3) */
//SENSOR_UNIT_HEART_RT_BPM = 0x2C00; /**< Heart Rate unit: beats/minute (Bpm) */
//SENSOR_UNIT_BLOOD_PRS_SYS = 0x2D00; /**< Blood Pressure unit: Systolic mmHg (upper number) */
//SENSOR_UNIT_BLOOD_PRS_DIA = 0x2D01; /**< Blood Pressure unit: Diastolic mmHg (lower number)*/
//SENSOR_UNIT_MUSCLE_MS_KG = 0x2E00; /**< Muscle Mass unit: kilogram (kg) */
//SENSOR_UNIT_FAT_MS_KG = 0x2F00; /**< Fat Mass unit: kilogram (kg) */
//SENSOR_UNIT_BONE_MS_KG = 0x3000; /**< Bone Mass unit: kilogram (kg) */
//SENSOR_UNIT_TBW_KG = 0x3100; /**< Total Body Water unit: kilogram (kg) */
//SENSOR_UNIT_BMR_J = 0x3200; /**< Basic Metabolic Rate unit: joule (J)*/
//SENSOR_UNIT_BMI_IDX = 0x3300; /**< Body Mass Index unit: BMI Index */
//SENSOR_UNIT_ACCEL_X_MS2 = 0x3400; /**< Acceleration, X-axis unit: (m/s2) */
//SENSOR_UNIT_ACCEL_Y_MS2 = 0x3500; /**< Acceleration, Y-axis unit: (m/s2) */
//SENSOR_UNIT_ACCEL_Z_MS2 = 0x3600; /**< Acceleration, Z-axis unit: (m/s2) */
//SENSOR_UNIT_SMOKE_DEN_PERC = 0x3700; /**< Smoke Density unit: Percentage value */
//SENSOR_UNIT_WATER_FLW_LHR = 0x3800; /**< Water Flow unit: liter/hour (l/h) */
//SENSOR_UNIT_WATER_PRS_KPA = 0x3900; /**< Water Pressure unit: kilopascal (kPa)*/
//SENSOR_UNIT_RF_SGN_RSSI = 0x3A00; /**< RF Signal Strength unit: RSSI (Percentage value) */
//SENSOR_UNIT_RF_SGN_DBM = 0x3A01; /**< RF Signal Strength unit: (dBm) */
//SENSOR_UNIT_PM_10_MOLE = 0x3B00; /**< Mole per cubic meter (mol/m3)*/
//SENSOR_UNIT_PM_10_UG = 0x3B01; /**< Microgram per cubic meter (ug/m3)*/
//SENSOR_UNIT_RESPI_RATE_BPM = 0x3C00; /**< Breaths per minute (bpm)*/
//SENSOR_UNIT_REL_MOD_PERC = 0x3D00; /**< Percentage value (%)*/
//SENSOR_UNIT_BOILER_WTR_TEMP_C = 0x3E00; /**< Celcius (C)*/
//SENSOR_UNIT_DHW_TEMP_C = 0x3F00; /**< Celcius (C)*/
//SENSOR_UNIT_OUTSIDE_TEMP_C = 0x4000; /**< Celcius (C)*/
//SENSOR_UNIT_EXHAUST_TEMP_C = 0x4100; /**< Celcius (C)*/
//SENSOR_UNIT_WATER_CHLOR_LVL_MGL = 0x4200; /**< Milligram per liter (mg/l)*/
//SENSOR_UNIT_WATER_ACID_PH = 0x4300; /**< Acidity (pH)*/
//SENSOR_UNIT_WATER_OXI_RED_MV = 0x4400; /**< MilliVolt (mV)*/
