# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/smoke.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/smoke.proto\x12\x08vemmiopb\"\xac\x01\n\x0bSmokeReport\x12+\n\x05state\x18\x01 \x01(\x0e\x32\x1c.vemmiopb.SmokeDetectorState\x12\x37\n\x0breplacement\x18\x02 \x01(\x0e\x32\".vemmiopb.SmokeDetectorReplacement\x12\x37\n\x0bmaintenance\x18\x03 \x01(\x0e\x32\".vemmiopb.SmokeDetectorMaintenance*\xde\x01\n\x12SmokeDetectorState\x12\x1b\n\x17SMOKE_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11SMOKE_STATE_CLEAR\x10\x01\x12\x18\n\x14SMOKE_STATE_DETECTED\x10\x02\x12\x14\n\x10SMOKE_STATE_TEST\x10\x03\x12\x18\n\x14SMOKE_STATE_SILENCED\x10\x04\x12$\n SMOKE_STATE_REPLACEMENT_REQUIRED\x10\x05\x12$\n SMOKE_STATE_MAINTENANCE_REQUIRED\x10\x06*X\n\x18SmokeDetectorReplacement\x12!\n\x1dSMOKE_REPLACEMENT_UNSPECIFIED\x10\x00\x12\x19\n\x15SMOKE_REPLACEMENT_EOL\x10\x01*\x8e\x01\n\x18SmokeDetectorMaintenance\x12!\n\x1dSMOKE_MAINTENANCE_UNSPECIFIED\x10\x00\x12)\n%SMOKE_MAINTENANCE_PERIODIC_INSPECTION\x10\x01\x12$\n SMOKE_MAINTENANCE_DUST_IN_DEVICE\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.smoke_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _SMOKEDETECTORSTATE._serialized_start=215
  _SMOKEDETECTORSTATE._serialized_end=437
  _SMOKEDETECTORREPLACEMENT._serialized_start=439
  _SMOKEDETECTORREPLACEMENT._serialized_end=527
  _SMOKEDETECTORMAINTENANCE._serialized_start=530
  _SMOKEDETECTORMAINTENANCE._serialized_end=672
  _SMOKEREPORT._serialized_start=40
  _SMOKEREPORT._serialized_end=212
# @@protoc_insertion_point(module_scope)
