# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/firmware.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvemmio_client/firmware.proto\x12\x08vemmiopb\",\n\rFirmwareChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05index\x18\x02 \x01(\x05\"$\n\x10\x46irmwareChunkAck\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\":\n\x16\x46irmwareUpgradeRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0e\n\x06sha256\x18\x02 \x01(\t\"\x14\n\x12\x46irmwareUpgradeAck\"(\n\x15\x46irmwareUpdateRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x18\n\x16\x46irmwareUpdateResponse\"\x1e\n\x1c\x46irmwareLatestVersionRequest\"0\n\x1d\x46irmwareLatestVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"o\n\x1a\x46irmwareUpdateStatusReport\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.vemmiopb.FirmwareUpdateStatus\x12\x10\n\x08progress\x18\x02 \x01(\r\x12\x0f\n\x07version\x18\x03 \x01(\t*\xd1\x01\n\x14\x46irmwareUpdateStatus\x12\"\n\x1e\x46IRMWARE_UPDATE_STATUS_UNKNOWN\x10\x00\x12&\n\"FIRMWARE_UPDATE_STATUS_IN_PROGRESS\x10\x01\x12#\n\x1f\x46IRMWARE_UPDATE_STATUS_COMPLETE\x10\x02\x12!\n\x1d\x46IRMWARE_UPDATE_STATUS_FAILED\x10\x03\x12%\n!FIRMWARE_UPDATE_STATUS_UP_TO_DATE\x10\x04\x32\xac\x01\n\x08\x46irmware\x12I\n\x0e\x46irmwareUpload\x12\x17.vemmiopb.FirmwareChunk\x1a\x1a.vemmiopb.FirmwareChunkAck(\x01\x30\x01\x12U\n\x0f\x46irmwareUpgrade\x12 .vemmiopb.FirmwareUpgradeRequest\x1a\x1c.vemmiopb.FirmwareUpgradeAck(\x01\x30\x01\x32\xd0\x01\n\x0f\x46irmwareService\x12S\n\x0e\x46irmwareUpdate\x12\x1f.vemmiopb.FirmwareUpdateRequest\x1a .vemmiopb.FirmwareUpdateResponse\x12h\n\x15\x46irmwareLatestVersion\x12&.vemmiopb.FirmwareLatestVersionRequest\x1a\'.vemmiopb.FirmwareLatestVersionResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.firmware_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _FIRMWAREUPDATESTATUS._serialized_start=472
  _FIRMWAREUPDATESTATUS._serialized_end=681
  _FIRMWARECHUNK._serialized_start=42
  _FIRMWARECHUNK._serialized_end=86
  _FIRMWARECHUNKACK._serialized_start=88
  _FIRMWARECHUNKACK._serialized_end=124
  _FIRMWAREUPGRADEREQUEST._serialized_start=126
  _FIRMWAREUPGRADEREQUEST._serialized_end=184
  _FIRMWAREUPGRADEACK._serialized_start=186
  _FIRMWAREUPGRADEACK._serialized_end=206
  _FIRMWAREUPDATEREQUEST._serialized_start=208
  _FIRMWAREUPDATEREQUEST._serialized_end=248
  _FIRMWAREUPDATERESPONSE._serialized_start=250
  _FIRMWAREUPDATERESPONSE._serialized_end=274
  _FIRMWARELATESTVERSIONREQUEST._serialized_start=276
  _FIRMWARELATESTVERSIONREQUEST._serialized_end=306
  _FIRMWARELATESTVERSIONRESPONSE._serialized_start=308
  _FIRMWARELATESTVERSIONRESPONSE._serialized_end=356
  _FIRMWAREUPDATESTATUSREPORT._serialized_start=358
  _FIRMWAREUPDATESTATUSREPORT._serialized_end=469
  _FIRMWARE._serialized_start=684
  _FIRMWARE._serialized_end=856
  _FIRMWARESERVICE._serialized_start=859
  _FIRMWARESERVICE._serialized_end=1067
# @@protoc_insertion_point(module_scope)
