# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/admin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/admin.proto\x12\x08vemmiopb\"\x12\n\x10WalkNodesRequest\"!\n\x11WalkNodesResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\",\n\x0bLogsRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x19\n\tLogsChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x32\xc5\x01\n\x05\x41\x64min\x12\x46\n\tWalkNodes\x12\x1a.vemmiopb.WalkNodesRequest\x1a\x1b.vemmiopb.WalkNodesResponse0\x01\x12\x38\n\x08ReadLogs\x12\x15.vemmiopb.LogsRequest\x1a\x13.vemmiopb.LogsChunk0\x01\x12:\n\nFollowLogs\x12\x15.vemmiopb.LogsRequest\x1a\x13.vemmiopb.LogsChunk0\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.admin_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _WALKNODESREQUEST._serialized_start=39
  _WALKNODESREQUEST._serialized_end=57
  _WALKNODESRESPONSE._serialized_start=59
  _WALKNODESRESPONSE._serialized_end=92
  _LOGSREQUEST._serialized_start=94
  _LOGSREQUEST._serialized_end=138
  _LOGSCHUNK._serialized_start=140
  _LOGSCHUNK._serialized_end=165
  _ADMIN._serialized_start=168
  _ADMIN._serialized_end=365
# @@protoc_insertion_point(module_scope)
