# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/gateway.proto\x12\x08vemmiopb\"\x0f\n\rRebootRequest\"\x10\n\x0eRebootResponse\"\x1e\n\x0eRestartRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x11\n\x0fRestartResponse\"\x10\n\x0eSupportRequest\"\x11\n\x0fSupportResponse2\x8f\x02\n\x07Gateway\x12;\n\x06Reboot\x12\x17.vemmiopb.RebootRequest\x1a\x18.vemmiopb.RebootResponse\x12>\n\x07Restart\x12\x18.vemmiopb.RestartRequest\x1a\x19.vemmiopb.RestartResponse\x12\x43\n\x0cStartSupport\x12\x18.vemmiopb.SupportRequest\x1a\x19.vemmiopb.SupportResponse\x12\x42\n\x0bStopSupport\x12\x18.vemmiopb.SupportRequest\x1a\x19.vemmiopb.SupportResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.gateway_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _REBOOTREQUEST._serialized_start=41
  _REBOOTREQUEST._serialized_end=56
  _REBOOTRESPONSE._serialized_start=58
  _REBOOTRESPONSE._serialized_end=74
  _RESTARTREQUEST._serialized_start=76
  _RESTARTREQUEST._serialized_end=106
  _RESTARTRESPONSE._serialized_start=108
  _RESTARTRESPONSE._serialized_end=125
  _SUPPORTREQUEST._serialized_start=127
  _SUPPORTREQUEST._serialized_end=143
  _SUPPORTRESPONSE._serialized_start=145
  _SUPPORTRESPONSE._serialized_end=162
  _GATEWAY._serialized_start=165
  _GATEWAY._serialized_end=436
# @@protoc_insertion_point(module_scope)
