# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/doorbell.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvemmio_client/doorbell.proto\x12\x08vemmiopb\"_\n\x0e\x44oorbellReport\x12-\n\x05state\x18\x01 \x01(\x0e\x32\x1e.vemmiopb.DoorbellReport.State\"\x1e\n\x05State\x12\t\n\x05\x43LEAR\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.doorbell_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _DOORBELLREPORT._serialized_start=42
  _DOORBELLREPORT._serialized_end=137
  _DOORBELLREPORT_STATE._serialized_start=107
  _DOORBELLREPORT_STATE._serialized_end=137
# @@protoc_insertion_point(module_scope)
