# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/zigbee.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import devices_pb2 as vemmio__client_dot_devices__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/zigbee.proto\x12\x08vemmiopb\x1a\x1bvemmio_client/devices.proto\x1a\x1cvemmio_client/metadata.proto\"\x16\n\x14ZigbeeIncludeRequest\":\n\x15ZigbeeIncludeResponse\x12!\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x10.vemmiopb.Device\"B\n\x14ZigbeeExcludeRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.ZigbeeMetadata\"\x17\n\x15ZigbeeExcludeResponse\"\x14\n\x12ZigbeeNodesRequest\":\n\x13ZigbeeNodesResponse\x12#\n\x05nodes\x18\x01 \x03(\x0b\x32\x14.vemmiopb.ZigbeeNode\"W\n\nZigbeeNode\x12\x11\n\tieee_addr\x18\x01 \x01(\x05\x12\x12\n\neui64_addr\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\x05\x12\x10\n\x08\x63lusters\x18\x04 \x03(\x05\x32\xfb\x01\n\x06Zigbee\x12P\n\rZigbeeInclude\x12\x1e.vemmiopb.ZigbeeIncludeRequest\x1a\x1f.vemmiopb.ZigbeeIncludeResponse\x12P\n\rZigbeeExclude\x12\x1e.vemmiopb.ZigbeeExcludeRequest\x1a\x1f.vemmiopb.ZigbeeExcludeResponse\x12M\n\x0eZigbeeGetNodes\x12\x1c.vemmiopb.ZigbeeNodesRequest\x1a\x1d.vemmiopb.ZigbeeNodesResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.zigbee_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ZIGBEEINCLUDEREQUEST._serialized_start=99
  _ZIGBEEINCLUDEREQUEST._serialized_end=121
  _ZIGBEEINCLUDERESPONSE._serialized_start=123
  _ZIGBEEINCLUDERESPONSE._serialized_end=181
  _ZIGBEEEXCLUDEREQUEST._serialized_start=183
  _ZIGBEEEXCLUDEREQUEST._serialized_end=249
  _ZIGBEEEXCLUDERESPONSE._serialized_start=251
  _ZIGBEEEXCLUDERESPONSE._serialized_end=274
  _ZIGBEENODESREQUEST._serialized_start=276
  _ZIGBEENODESREQUEST._serialized_end=296
  _ZIGBEENODESRESPONSE._serialized_start=298
  _ZIGBEENODESRESPONSE._serialized_end=356
  _ZIGBEENODE._serialized_start=358
  _ZIGBEENODE._serialized_end=445
  _ZIGBEE._serialized_start=448
  _ZIGBEE._serialized_end=699
# @@protoc_insertion_point(module_scope)
