syntax = "proto3";

package vemmiopb;

option go_package = "./vemmiopb";
option java_multiple_files = true;
option java_package = "com.vemmio.ha.integration.vemmio.rpc.vemmiopb";

message SmokeReport {
  SmokeDetectorState state = 1;
  SmokeDetectorReplacement replacement = 2;
  SmokeDetectorMaintenance maintenance = 3;
}

enum SmokeDetectorState {
  SMOKE_STATE_UNSPECIFIED = 0;
  SMOKE_STATE_CLEAR = 1;
  SMOKE_STATE_DETECTED = 2;
  SMOKE_STATE_TEST = 3;
  SMOKE_STATE_SILENCED = 4;
  SMOKE_STATE_REPLACEMENT_REQUIRED = 5;
  SMOKE_STATE_MAINTENANCE_REQUIRED = 6;
}

enum SmokeDetectorReplacement {
  SMOKE_REPLACEMENT_UNSPECIFIED = 0;
  SMOKE_REPLACEMENT_EOL = 1;
}

enum SmokeDetectorMaintenance {
  SMOKE_MAINTENANCE_UNSPECIFIED = 0;
  SMOKE_MAINTENANCE_PERIODIC_INSPECTION = 1;
  SMOKE_MAINTENANCE_DUST_IN_DEVICE = 2;
}
