# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!vemmio_client/configuration.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"F\n\x18\x43onfigurationListRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"K\n\x19\x43onfigurationListResponse\x12.\n\x07options\x18\x01 \x03(\x0b\x32\x1d.vemmiopb.ConfigurationOption\"T\n\x17\x43onfigurationGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05index\x18\x02 \x01(\x05\"G\n\x18\x43onfigurationGetResponse\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.vemmiopb.ConfigurationValue\"\x81\x01\n\x17\x43onfigurationSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05index\x18\x02 \x01(\x05\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x1c.vemmiopb.ConfigurationValue\"\x1a\n\x18\x43onfigurationSetResponse\"q\n\x13\x43onfigurationOption\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04help\x18\x03 \x01(\t\x12.\n\x04type\x18\x04 \x01(\x0e\x32 .vemmiopb.ConfigurationValueType\"S\n\x12\x43onfigurationValue\x12\x34\n\x06scalar\x18\x01 \x01(\x0b\x32\".vemmiopb.ConfigurationValueScalarH\x00\x42\x07\n\x05value\"\xbd\x02\n\x18\x43onfigurationValueScalar\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0buint8_value\x18\x02 \x01(\rH\x00\x12\x16\n\x0cuint16_value\x18\x03 \x01(\rH\x00\x12\x16\n\x0cuint32_value\x18\x04 \x01(\rH\x00\x12\x16\n\x0cuint64_value\x18\x05 \x01(\x04H\x00\x12\x14\n\nint8_value\x18\x06 \x01(\x05H\x00\x12\x15\n\x0bint16_value\x18\x07 \x01(\x05H\x00\x12\x15\n\x0bint32_value\x18\x08 \x01(\x05H\x00\x12\x15\n\x0bint64_value\x18\t \x01(\x03H\x00\x12\x17\n\rfloat32_value\x18\n \x01(\x02H\x00\x12\x17\n\rfloat64_value\x18\x0b \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x0c \x01(\tH\x00\x42\x07\n\x05value*\xf6\x03\n\x16\x43onfigurationValueType\x12&\n\"CONFIGURATION_VALUE_TYPE_UNDEFINED\x10\x00\x12!\n\x1d\x43ONFIGURATION_VALUE_TYPE_BOOL\x10\x01\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_UINT8\x10\x02\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_UINT16\x10\x03\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_UINT32\x10\x04\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_UINT64\x10\x05\x12!\n\x1d\x43ONFIGURATION_VALUE_TYPE_INT8\x10\x06\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_INT16\x10\x07\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_INT32\x10\x08\x12\"\n\x1e\x43ONFIGURATION_VALUE_TYPE_INT64\x10\t\x12$\n CONFIGURATION_VALUE_TYPE_FLOAT32\x10\n\x12$\n CONFIGURATION_VALUE_TYPE_FLOAT64\x10\x0b\x12#\n\x1f\x43ONFIGURATION_VALUE_TYPE_STRING\x10\x0c\x32\xa3\x02\n\rConfiguration\x12\\\n\x11\x43onfigurationList\x12\".vemmiopb.ConfigurationListRequest\x1a#.vemmiopb.ConfigurationListResponse\x12Y\n\x10\x43onfigurationGet\x12!.vemmiopb.ConfigurationGetRequest\x1a\".vemmiopb.ConfigurationGetResponse\x12Y\n\x10\x43onfigurationSet\x12!.vemmiopb.ConfigurationSetRequest\x1a\".vemmiopb.ConfigurationSetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _CONFIGURATIONVALUETYPE._serialized_start=1066
  _CONFIGURATIONVALUETYPE._serialized_end=1568
  _CONFIGURATIONLISTREQUEST._serialized_start=77
  _CONFIGURATIONLISTREQUEST._serialized_end=147
  _CONFIGURATIONLISTRESPONSE._serialized_start=149
  _CONFIGURATIONLISTRESPONSE._serialized_end=224
  _CONFIGURATIONGETREQUEST._serialized_start=226
  _CONFIGURATIONGETREQUEST._serialized_end=310
  _CONFIGURATIONGETRESPONSE._serialized_start=312
  _CONFIGURATIONGETRESPONSE._serialized_end=383
  _CONFIGURATIONSETREQUEST._serialized_start=386
  _CONFIGURATIONSETREQUEST._serialized_end=515
  _CONFIGURATIONSETRESPONSE._serialized_start=517
  _CONFIGURATIONSETRESPONSE._serialized_end=543
  _CONFIGURATIONOPTION._serialized_start=545
  _CONFIGURATIONOPTION._serialized_end=658
  _CONFIGURATIONVALUE._serialized_start=660
  _CONFIGURATIONVALUE._serialized_end=743
  _CONFIGURATIONVALUESCALAR._serialized_start=746
  _CONFIGURATIONVALUESCALAR._serialized_end=1063
  _CONFIGURATION._serialized_start=1571
  _CONFIGURATION._serialized_end=1862
# @@protoc_insertion_point(module_scope)
