# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/meter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/meter.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/units.proto\"[\n\x0fMeterGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x1c\n\x04unit\x18\x02 \x01(\x0e\x32\x0e.vemmiopb.Unit\"?\n\x10MeterGetResponse\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"?\n\x11MeterResetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x14\n\x12MeterResetResponse\":\n\x0bMeterReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\x32\x93\x01\n\x05Meter\x12\x41\n\x08MeterGet\x12\x19.vemmiopb.MeterGetRequest\x1a\x1a.vemmiopb.MeterGetResponse\x12G\n\nMeterReset\x12\x1b.vemmiopb.MeterResetRequest\x1a\x1c.vemmiopb.MeterResetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.meter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _METERGETREQUEST._serialized_start=96
  _METERGETREQUEST._serialized_end=187
  _METERGETRESPONSE._serialized_start=189
  _METERGETRESPONSE._serialized_end=252
  _METERRESETREQUEST._serialized_start=254
  _METERRESETREQUEST._serialized_end=317
  _METERRESETRESPONSE._serialized_start=319
  _METERRESETRESPONSE._serialized_end=339
  _METERREPORT._serialized_start=341
  _METERREPORT._serialized_end=399
  _METER._serialized_start=402
  _METER._serialized_end=549
# @@protoc_insertion_point(module_scope)
