# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/roller_shutter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vemmio_client/roller_shutter.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"B\n\x14RollerShutterRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"T\n\x17RollerShutterSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05level\x18\x02 \x01(\x05\"\x17\n\x15RollerShutterResponse\")\n\x18RollerShutterLevelReport\x12\r\n\x05value\x18\x01 \x01(\x05\x32\x94\x02\n\rRollerShutter\x12T\n\x11RollerShutterOpen\x12\x1e.vemmiopb.RollerShutterRequest\x1a\x1f.vemmiopb.RollerShutterResponse\x12U\n\x12RollerShutterClose\x12\x1e.vemmiopb.RollerShutterRequest\x1a\x1f.vemmiopb.RollerShutterResponse\x12V\n\x10RollerShutterSet\x12!.vemmiopb.RollerShutterSetRequest\x1a\x1f.vemmiopb.RollerShutterResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.roller_shutter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ROLLERSHUTTERREQUEST._serialized_start=78
  _ROLLERSHUTTERREQUEST._serialized_end=144
  _ROLLERSHUTTERSETREQUEST._serialized_start=146
  _ROLLERSHUTTERSETREQUEST._serialized_end=230
  _ROLLERSHUTTERRESPONSE._serialized_start=232
  _ROLLERSHUTTERRESPONSE._serialized_end=255
  _ROLLERSHUTTERLEVELREPORT._serialized_start=257
  _ROLLERSHUTTERLEVELREPORT._serialized_end=298
  _ROLLERSHUTTER._serialized_start=301
  _ROLLERSHUTTER._serialized_end=577
# @@protoc_insertion_point(module_scope)
