# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/reports.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from vemmio_client import accelerometer_pb2 as vemmio__client_dot_accelerometer__pb2
from vemmio_client import battery_pb2 as vemmio__client_dot_battery__pb2
from vemmio_client import bsensor_pb2 as vemmio__client_dot_bsensor__pb2
from vemmio_client import carbon_dioxide_pb2 as vemmio__client_dot_carbon__dioxide__pb2
from vemmio_client import carbon_monoxide_pb2 as vemmio__client_dot_carbon__monoxide__pb2
from vemmio_client import color_pb2 as vemmio__client_dot_color__pb2
from vemmio_client import door_pb2 as vemmio__client_dot_door__pb2
from vemmio_client import doorbell_pb2 as vemmio__client_dot_doorbell__pb2
from vemmio_client import emergency_pb2 as vemmio__client_dot_emergency__pb2
from vemmio_client import firmware_pb2 as vemmio__client_dot_firmware__pb2
from vemmio_client import flood_pb2 as vemmio__client_dot_flood__pb2
from vemmio_client import gate_pb2 as vemmio__client_dot_gate__pb2
from vemmio_client import level_pb2 as vemmio__client_dot_level__pb2
from vemmio_client import lock_pb2 as vemmio__client_dot_lock__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import meter_pb2 as vemmio__client_dot_meter__pb2
from vemmio_client import power_source_pb2 as vemmio__client_dot_power__source__pb2
from vemmio_client import remote_pb2 as vemmio__client_dot_remote__pb2
from vemmio_client import roller_shutter_pb2 as vemmio__client_dot_roller__shutter__pb2
from vemmio_client import seismic_pb2 as vemmio__client_dot_seismic__pb2
from vemmio_client import sensor_pb2 as vemmio__client_dot_sensor__pb2
from vemmio_client import siren_pb2 as vemmio__client_dot_siren__pb2
from vemmio_client import smoke_pb2 as vemmio__client_dot_smoke__pb2
from vemmio_client import status_pb2 as vemmio__client_dot_status__pb2
from vemmio_client import structure_pb2 as vemmio__client_dot_structure__pb2
from vemmio_client import switch_pb2 as vemmio__client_dot_switch__pb2
from vemmio_client import tamper_pb2 as vemmio__client_dot_tamper__pb2
from vemmio_client import taptap_pb2 as vemmio__client_dot_taptap__pb2
from vemmio_client import temperature_pb2 as vemmio__client_dot_temperature__pb2
from vemmio_client import thermostat_pb2 as vemmio__client_dot_thermostat__pb2
from vemmio_client import ultraviolet_pb2 as vemmio__client_dot_ultraviolet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/reports.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!vemmio_client/accelerometer.proto\x1a\x1bvemmio_client/battery.proto\x1a\x1bvemmio_client/bsensor.proto\x1a\"vemmio_client/carbon_dioxide.proto\x1a#vemmio_client/carbon_monoxide.proto\x1a\x19vemmio_client/color.proto\x1a\x18vemmio_client/door.proto\x1a\x1cvemmio_client/doorbell.proto\x1a\x1dvemmio_client/emergency.proto\x1a\x1cvemmio_client/firmware.proto\x1a\x19vemmio_client/flood.proto\x1a\x18vemmio_client/gate.proto\x1a\x19vemmio_client/level.proto\x1a\x18vemmio_client/lock.proto\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/meter.proto\x1a vemmio_client/power_source.proto\x1a\x1avemmio_client/remote.proto\x1a\"vemmio_client/roller_shutter.proto\x1a\x1bvemmio_client/seismic.proto\x1a\x1avemmio_client/sensor.proto\x1a\x19vemmio_client/siren.proto\x1a\x19vemmio_client/smoke.proto\x1a\x1avemmio_client/status.proto\x1a\x1dvemmio_client/structure.proto\x1a\x1avemmio_client/switch.proto\x1a\x1avemmio_client/tamper.proto\x1a\x1avemmio_client/taptap.proto\x1a\x1fvemmio_client/temperature.proto\x1a\x1evemmio_client/thermostat.proto\x1a\x1fvemmio_client/ultraviolet.proto\"\x0f\n\rReportRequest\"\xc9\x0f\n\x0c\x44\x65viceReport\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06switch\x18\x03 \x01(\x0b\x32\x16.vemmiopb.SwitchReportH\x00\x12,\n\x0bpower_meter\x18\x04 \x01(\x0b\x32\x15.vemmiopb.MeterReportH\x00\x12*\n\tgas_meter\x18\x05 \x01(\x0b\x32\x15.vemmiopb.MeterReportH\x00\x12,\n\x0bwater_meter\x18\x06 \x01(\x0b\x32\x15.vemmiopb.MeterReportH\x00\x12/\n\nopen_close\x18\x07 \x01(\x0b\x32\x19.vemmiopb.OpenCloseReportH\x00\x12&\n\x05smoke\x18\x08 \x01(\x0b\x32\x15.vemmiopb.SmokeReportH\x00\x12(\n\x06motion\x18\t \x01(\x0b\x32\x16.vemmiopb.MotionReportH\x00\x12&\n\x05\x66lood\x18\n \x01(\x0b\x32\x15.vemmiopb.FloodReportH\x00\x12\x44\n\x15\x63\x61rbon_monoxide_state\x18\x0b \x01(\x0b\x32#.vemmiopb.CarbonMonoxideStateReportH\x00\x12\x32\n\x0btemperature\x18\x0c \x01(\x0b\x32\x1b.vemmiopb.TemperatureReportH\x00\x12,\n\x08humidity\x18\r \x01(\x0b\x32\x18.vemmiopb.HumidityReportH\x00\x12\x34\n\x0cillumination\x18\x0e \x01(\x0b\x32\x1c.vemmiopb.IlluminationReportH\x00\x12.\n\tdirection\x18\x0f \x01(\x0b\x32\x19.vemmiopb.DirectionReportH\x00\x12\x39\n\x0fthermostat_mode\x18\x10 \x01(\x0b\x32\x1e.vemmiopb.ThermostatModeReportH\x00\x12\x41\n\x13thermostat_setpoint\x18\x11 \x01(\x0b\x32\".vemmiopb.ThermostatSetpointReportH\x00\x12@\n\x13thermostat_fan_mode\x18\x12 \x01(\x0b\x32!.vemmiopb.ThermostatFanModeReportH\x00\x12(\n\x06tamper\x18\x13 \x01(\x0b\x32\x16.vemmiopb.TamperReportH\x00\x12.\n\temergency\x18\x14 \x01(\x0b\x32\x19.vemmiopb.EmergencyReportH\x00\x12$\n\x04\x64oor\x18\x15 \x01(\x0b\x32\x14.vemmiopb.DoorReportH\x00\x12)\n\x07tap_tap\x18\x16 \x01(\x0b\x32\x16.vemmiopb.TapTapReportH\x00\x12&\n\x05\x63olor\x18\x17 \x01(\x0b\x32\x15.vemmiopb.ColorReportH\x00\x12&\n\x05level\x18\x18 \x01(\x0b\x32\x15.vemmiopb.LevelReportH\x00\x12*\n\x07\x62\x61ttery\x18\x19 \x01(\x0b\x32\x17.vemmiopb.BatteryReportH\x00\x12(\n\x06remote\x18\x1a \x01(\x0b\x32\x16.vemmiopb.RemoteReportH\x00\x12$\n\x04lock\x18\x1b \x01(\x0b\x32\x14.vemmiopb.LockReportH\x00\x12,\n\x08\x64oorbell\x18\x1d \x01(\x0b\x32\x18.vemmiopb.DoorbellReportH\x00\x12\x33\n\x0cpower_source\x18\x1e \x01(\x0b\x32\x1b.vemmiopb.PowerSourceReportH\x00\x12&\n\x05siren\x18\x1f \x01(\x0b\x32\x15.vemmiopb.SirenReportH\x00\x12$\n\x04tone\x18  \x01(\x0b\x32\x14.vemmiopb.ToneReportH\x00\x12(\n\x06volume\x18! \x01(\x0b\x32\x16.vemmiopb.VolumeReportH\x00\x12\x36\n\raccelerometer\x18\" \x01(\x0b\x32\x1d.vemmiopb.AccelerometerReportH\x00\x12=\n\x11seismic_intensity\x18# \x01(\x0b\x32 .vemmiopb.SeismicIntensityReportH\x00\x12=\n\x11seismic_magnitude\x18$ \x01(\x0b\x32 .vemmiopb.SeismicMagnitudeReportH\x00\x12\x42\n\x14roller_shutter_level\x18% \x01(\x0b\x32\".vemmiopb.RollerShutterLevelReportH\x00\x12\x37\n\x0e\x63\x61rbon_dioxide\x18& \x01(\x0b\x32\x1d.vemmiopb.CarbonDioxideReportH\x00\x12\x44\n\x15\x63\x61rbon_monoxide_value\x18\' \x01(\x0b\x32#.vemmiopb.CarbonMonoxideValueReportH\x00\x12\x32\n\x0bultraviolet\x18( \x01(\x0b\x32\x1b.vemmiopb.UltravioletReportH\x00\x12$\n\x04gate\x18) \x01(\x0b\x32\x14.vemmiopb.GateReportH\x00\x42\x08\n\x06reportJ\x04\x08\x1c\x10\x1d\"\xd7\x01\n\x12\x43onnectivityReport\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x05state\x18\x02 \x01(\x0e\x32\".vemmiopb.ConnectivityReport.State\x12)\n\x06uptime\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"4\n\x05State\x12\x10\n\x0c\x44ISCONNECTED\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\n\n\x06UPTIME\x10\x02\"\xb9\x02\n\rGatewayReport\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x34\n\x0c\x63onnectivity\x18\x02 \x01(\x0b\x32\x1c.vemmiopb.ConnectivityReportH\x00\x12(\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x16.vemmiopb.DeviceReportH\x00\x12\x33\n\x0cstatus_check\x18\x05 \x01(\x0b\x32\x1b.vemmiopb.StatusCheckReportH\x00\x12\x46\n\x16\x66irmware_update_status\x18\x06 \x01(\x0b\x32$.vemmiopb.FirmwareUpdateStatusReportH\x00\x12.\n\tstructure\x18\x07 \x01(\x0b\x32\x19.vemmiopb.StructureReportH\x00\x42\x08\n\x06reportJ\x04\x08\x04\x10\x05\x32I\n\x07Reports\x12>\n\tSubscribe\x12\x17.vemmiopb.ReportRequest\x1a\x16.vemmiopb.DeviceReport0\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.reports_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _REPORTREQUEST._serialized_start=1029
  _REPORTREQUEST._serialized_end=1044
  _DEVICEREPORT._serialized_start=1047
  _DEVICEREPORT._serialized_end=3040
  _CONNECTIVITYREPORT._serialized_start=3043
  _CONNECTIVITYREPORT._serialized_end=3258
  _CONNECTIVITYREPORT_STATE._serialized_start=3206
  _CONNECTIVITYREPORT_STATE._serialized_end=3258
  _GATEWAYREPORT._serialized_start=3261
  _GATEWAYREPORT._serialized_end=3574
  _REPORTS._serialized_start=3576
  _REPORTS._serialized_end=3649
# @@protoc_insertion_point(module_scope)
