from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

AMPERE: Unit
CELSIUS: Unit
CUBIC_FEET: Unit
CUBIC_METERS: Unit
DEGREES: Unit
DESCRIPTOR: _descriptor.FileDescriptor
FAHRENHEIT: Unit
KVAH: Unit
KWH: Unit
LUX: Unit
MERCALLI: Unit
METER_PER_SECOND_SQUARED: Unit
PARTS_PER_MILLION: Unit
PERCENTAGE: Unit
POWER_FACTOR: Unit
PULSE_COUNT: Unit
UNKNOWN: Unit
US_GALLONS: Unit
VOLT: Unit
WATT: Unit

class Unit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
