# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/carbon_dioxide.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vemmio_client/carbon_dioxide.proto\x12\x08vemmiopb\"\xb4\x01\n\x13\x43\x61rbonDioxideReport\x12+\n\x05state\x18\x01 \x01(\x0e\x32\x1c.vemmiopb.CarbonDioxideState\x12\x37\n\x0breplacement\x18\x02 \x01(\x0e\x32\".vemmiopb.CarbonDioxideReplacement\x12\x37\n\x0bmaintenance\x18\x03 \x01(\x0e\x32\".vemmiopb.CarbonDioxideMaintenance*\x9d\x02\n\x12\x43\x61rbonDioxideState\x12$\n CARBON_DIOXIDE_STATE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43\x41RBON_DIOXIDE_STATE_CLEAR\x10\x01\x12!\n\x1d\x43\x41RBON_DIOXIDE_STATE_DETECTED\x10\x02\x12\x1d\n\x19\x43\x41RBON_DIOXIDE_STATE_TEST\x10\x03\x12!\n\x1d\x43\x41RBON_DIOXIDE_STATE_SILENCED\x10\x04\x12-\n)CARBON_DIOXIDE_STATE_REPLACEMENT_REQUIRED\x10\x05\x12-\n)CARBON_DIOXIDE_STATE_MAINTENANCE_REQUIRED\x10\x06*j\n\x18\x43\x61rbonDioxideReplacement\x12*\n&CARBON_DIOXIDE_REPLACEMENT_UNSPECIFIED\x10\x00\x12\"\n\x1e\x43\x41RBON_DIOXIDE_REPLACEMENT_EOL\x10\x01*z\n\x18\x43\x61rbonDioxideMaintenance\x12*\n&CARBON_DIOXIDE_MAINTENANCE_UNSPECIFIED\x10\x00\x12\x32\n.CARBON_DIOXIDE_MAINTENANCE_PERIODIC_INSPECTION\x10\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.carbon_dioxide_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _CARBONDIOXIDESTATE._serialized_start=232
  _CARBONDIOXIDESTATE._serialized_end=517
  _CARBONDIOXIDEREPLACEMENT._serialized_start=519
  _CARBONDIOXIDEREPLACEMENT._serialized_end=625
  _CARBONDIOXIDEMAINTENANCE._serialized_start=627
  _CARBONDIOXIDEMAINTENANCE._serialized_end=749
  _CARBONDIOXIDEREPORT._serialized_start=49
  _CARBONDIOXIDEREPORT._serialized_end=229
# @@protoc_insertion_point(module_scope)
