# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/lock.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/lock.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"^\n\x0eLockSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12 \n\x04mode\x18\x02 \x01(\x0e\x32\x12.vemmiopb.LockMode\"\x0e\n\x0cLockResponse\".\n\nLockReport\x12 \n\x04mode\x18\x01 \x01(\x0e\x32\x12.vemmiopb.LockMode*\xac\x01\n\x08LockMode\x12\x0e\n\nLOCK_UNSEC\x10\x00\x12\x14\n\x10LOCK_UNSEC_TMOUT\x10\x01\x12\x11\n\rLOCK_UNSEC_IN\x10\x10\x12\x17\n\x13LOCK_UNSEC_IN_TMOUT\x10\x11\x12\x12\n\x0eLOCK_UNSEC_OUT\x10 \x12\x18\n\x14LOCK_UNSEC_OUT_TMOUT\x10!\x12\x11\n\x0cLOCK_UNKNOWN\x10\xfe\x01\x12\r\n\x08LOCK_SEC\x10\xff\x01\x32\x43\n\x04Lock\x12;\n\x07LockSet\x12\x18.vemmiopb.LockSetRequest\x1a\x16.vemmiopb.LockResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.lock_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _LOCKMODE._serialized_start=229
  _LOCKMODE._serialized_end=401
  _LOCKSETREQUEST._serialized_start=68
  _LOCKSETREQUEST._serialized_end=162
  _LOCKRESPONSE._serialized_start=164
  _LOCKRESPONSE._serialized_end=178
  _LOCKREPORT._serialized_start=180
  _LOCKREPORT._serialized_end=226
  _LOCK._serialized_start=403
  _LOCK._serialized_end=470
# @@protoc_insertion_point(module_scope)
