# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/wifi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/wifi.proto\x12\x08vemmiopb\x1a\x1fgoogle/protobuf/timestamp.proto\"\x12\n\x10WiFiQueryRequest\"o\n\x11WiFiQueryResponse\x12+\n\ninterfaces\x18\x01 \x03(\x0b\x32\x17.vemmiopb.WiFiInterface\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x11\n\x0fWiFiScanRequest\"3\n\x10WiFiScanResponse\x12\x1f\n\x04\x62sss\x18\x01 \x03(\x0b\x32\x11.vemmiopb.WiFiBSS\"/\n\x12WiFiConnectRequest\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x0b\n\x03psk\x18\x02 \x01(\t\"\x15\n\x13WiFiConnectResponse\"}\n\rWiFiInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rhardware_addr\x18\x02 \x01(\x0c\x12\x1e\n\x03\x62ss\x18\x03 \x01(\x0b\x32\x11.vemmiopb.WiFiBSS\x12\'\n\x08stations\x18\x04 \x03(\x0b\x32\x15.vemmiopb.WiFiStation\"=\n\x07WiFiBSS\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x11\n\tfrequency\x18\x02 \x01(\x05\x12\x11\n\tlast_seen\x18\x03 \x01(\x03\"Y\n\x0bWiFiStation\x12\x15\n\rhardware_addr\x18\x01 \x01(\x0c\x12\x0e\n\x06signal\x18\x02 \x01(\x05\x12\x11\n\tconnected\x18\x03 \x01(\x03\x12\x10\n\x08inactive\x18\x04 \x01(\x03\x32\xdb\x01\n\x04WiFi\x12\x44\n\tWiFiQuery\x12\x1a.vemmiopb.WiFiQueryRequest\x1a\x1b.vemmiopb.WiFiQueryResponse\x12\x41\n\x08WiFiScan\x12\x19.vemmiopb.WiFiScanRequest\x1a\x1a.vemmiopb.WiFiScanResponse\x12J\n\x0bWiFiConnect\x12\x1c.vemmiopb.WiFiConnectRequest\x1a\x1d.vemmiopb.WiFiConnectResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.wifi_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _WIFIQUERYREQUEST._serialized_start=71
  _WIFIQUERYREQUEST._serialized_end=89
  _WIFIQUERYRESPONSE._serialized_start=91
  _WIFIQUERYRESPONSE._serialized_end=202
  _WIFISCANREQUEST._serialized_start=204
  _WIFISCANREQUEST._serialized_end=221
  _WIFISCANRESPONSE._serialized_start=223
  _WIFISCANRESPONSE._serialized_end=274
  _WIFICONNECTREQUEST._serialized_start=276
  _WIFICONNECTREQUEST._serialized_end=323
  _WIFICONNECTRESPONSE._serialized_start=325
  _WIFICONNECTRESPONSE._serialized_end=346
  _WIFIINTERFACE._serialized_start=348
  _WIFIINTERFACE._serialized_end=473
  _WIFIBSS._serialized_start=475
  _WIFIBSS._serialized_end=536
  _WIFISTATION._serialized_start=538
  _WIFISTATION._serialized_end=627
  _WIFI._serialized_start=630
  _WIFI._serialized_end=849
# @@protoc_insertion_point(module_scope)
