# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/battery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/battery.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"?\n\x11\x42\x61tteryGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"#\n\x12\x42\x61tteryGetResponse\x12\r\n\x05level\x18\x01 \x01(\x05\"\x1e\n\rBatteryReport\x12\r\n\x05level\x18\x01 \x01(\x05\x32R\n\x07\x42\x61ttery\x12G\n\nBatteryGet\x12\x1b.vemmiopb.BatteryGetRequest\x1a\x1c.vemmiopb.BatteryGetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.battery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _BATTERYGETREQUEST._serialized_start=71
  _BATTERYGETREQUEST._serialized_end=134
  _BATTERYGETRESPONSE._serialized_start=136
  _BATTERYGETRESPONSE._serialized_end=171
  _BATTERYREPORT._serialized_start=173
  _BATTERYREPORT._serialized_end=203
  _BATTERY._serialized_start=205
  _BATTERY._serialized_end=287
# @@protoc_insertion_point(module_scope)
