# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/addon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/addon.proto\x12\x08vemmiopb\"\x12\n\x10\x41\x64\x64onListRequest\"\x97\x01\n\x11\x41\x64\x64onListResponse\x12\x31\n\x06\x61\x64\x64ons\x18\x01 \x03(\x0b\x32!.vemmiopb.AddonListResponse.Addon\x1aO\n\x05\x41\x64\x64on\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12/\n\nthermostat\x18\x02 \x01(\x0b\x32\x19.vemmiopb.AddonThermostatH\x00\x42\x07\n\x05\x61\x64\x64on\"J\n\x19\x41\x64\x64onAddThermostatRequest\x12-\n\nthermostat\x18\x01 \x01(\x0b\x32\x19.vemmiopb.AddonThermostat\" \n\x10\x41\x64\x64onAddResponse\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"B\n\x0f\x41\x64\x64onThermostat\x12\x16\n\x0einput_filename\x18\x01 \x01(\t\x12\x17\n\x0foutput_filename\x18\x02 \x01(\t2\xa4\x01\n\x05\x41\x64\x64on\x12\x44\n\tAddonList\x12\x1a.vemmiopb.AddonListRequest\x1a\x1b.vemmiopb.AddonListResponse\x12U\n\x12\x41\x64\x64onAddThermostat\x12#.vemmiopb.AddonAddThermostatRequest\x1a\x1a.vemmiopb.AddonAddResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.addon_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ADDONLISTREQUEST._serialized_start=39
  _ADDONLISTREQUEST._serialized_end=57
  _ADDONLISTRESPONSE._serialized_start=60
  _ADDONLISTRESPONSE._serialized_end=211
  _ADDONLISTRESPONSE_ADDON._serialized_start=132
  _ADDONLISTRESPONSE_ADDON._serialized_end=211
  _ADDONADDTHERMOSTATREQUEST._serialized_start=213
  _ADDONADDTHERMOSTATREQUEST._serialized_end=287
  _ADDONADDRESPONSE._serialized_start=289
  _ADDONADDRESPONSE._serialized_end=321
  _ADDONTHERMOSTAT._serialized_start=323
  _ADDONTHERMOSTAT._serialized_end=389
  _ADDON._serialized_start=392
  _ADDON._serialized_end=556
# @@protoc_insertion_point(module_scope)
